//---------------------------------------------------------------------------
// Terawins Inc. Company Confidential Strictly Private
//
// $Archive: T138AF Reg.h $
// $Revision: 1.01 $
// $Author: Mehdi rahimi $
// $Date: 1391/3/2 16:14:23 $
//
// --------------------------------------------------------------------------

#ifndef  __T138AF_REG_H__
#define  __T138AF_REG_H__
								   
#define PAGE_OFFSET				0x02
#define T138AF          0x50					// T138AF I2C ADDRESS OR 0x40
#define T138AF_P1   				T138AF    + PAGE_OFFSET
#define T138AF_P2   				T138AF_P1 + PAGE_OFFSET
#define T138AF_P3				    T138AF_P2 + PAGE_OFFSET



#define IF_NDEFAULT(eval_reg)  ((eval_reg)!=(eval_reg##_DEFAULT))

//---------------------------------------------------------------------------
// The postfix of _REG defines its register address
// The postfix of _DEFAULT defines the default value of the register of the chip, 
// and these values should not be modified
//---------------------------------------------------------------------------

/* ADC Regs */
// define the ADC R/G/B current regiser [3:0]
#define ADC_R_CUR_REG				0x00
	#define ADC_R_CUR_DEFAULT			0x00
#define ADC_G_CUR_REG				0x01
	#define ADC_G_CUR_DEFAULT			0x00
#define ADC_B_CUR_REG				0x02
	#define ADC_B_CUR_DEFAULT			0x00
	
	#define ADC_R_CUR					0x00
	#define ADC_G_CUR					0x00
	#define ADC_B_CUR					0x00

// define the ADC clamping pulse placement and duration
//   [7:5] clamping pulse placement
//   [4:0] clamping pulse duration
#define ADC_CLP_PPD_REG				0x04
	#define ADC_CLP_PPD_DEFAULT			0x00
	#define ADC_CLP_PPD					0x00

//define the ADC Channel R Offset Tune Register
#define ADC_CH_R_OFFS_TUN_REG				0x05
#define ADC_CH_R_OFFS_TUN_PPD_DEFAULT		0x00
#define ADC_CH_R_OFFS_TUN_PPD               0x00
// define the ADC R/G/B static gain
//   [7:0] 
//   Note: ADC analog AGC selection (0x1A) should be enabled
#define ADC_R_SGAIN_REG				0x07
	#define ADC_R_SGAIN_DEFAULT			0x00
#define ADC_G_SGAIN_REG				0x08
	#define ADC_G_SGAIN_DEFAULT			0x00
#define ADC_B_SGAIN_REG				0x09
	#define ADC_B_SGAIN_DEFAULT			0x00
	#define ADC_R_SGAIN					0x60
	#define ADC_G_SGAIN					0x60
	#define ADC_B_SGAIN					0x60

// define the ADC R/G/B offset
//    [7:2]
#define ADC_R_OFFSET_REG			0x0A
	#define ADC_R_OFFSET_DEFAULT		0x80
	#define ADC_R_OFFSET				0x30
#define ADC_G_OFFSET_REG			0x0B
	#define ADC_G_OFFSET_DEFAULT		0x80
	#define ADC_G_OFFSET				0x30
#define ADC_B_OFFSET_REG			0x0C
	#define ADC_B_OFFSET_DEFAULT		0x80
	#define ADC_B_OFFSET				0x30

// define the ADC general control configuration register (R/W)
//   [7:6]  clamping mode 0: fixed window
//                                1: locked window
//                                2: self bias (default)
//                                3: fixed window
//   [5] DC clamping enable
//   [4] Clamping source selection
//   [3] Slicer threshold voltage selection 0: abouve auto bias (default)
//                                                     1: below auto bias
//   [2] DC calibration ready
//   [1] DC calibration enable
//   [0] DC calibration mode 0: minimum (default)
//                                   1: average
#define ADC_GENCTRL_REG				0x0D
	#define ADC_GENCTRL_DEFAULT			0x20
	#define ADC_GENCTRL					0x20

 //ADC General Control Configuration Register
  
//Bit        Access              Symbol              Description
//[7:6]      R/W                 CLPMD[1:0]          Clamping mode
//                                                   Mode          Type
//                                                    0, 3         Fixed window
//                                                    1, 2         Locked Window
//[5]        R/W                 DCEN                DC Clamping Enable
//[4]        R/W                 DCSEL               Clamping Source Selection
//[3]        R/W                 VMODE               Video mode:
//                                                    0: Analog RGB input
//                                                    1: CVBS/S-Video/YPbPr
//[2]        RO                  DC_CAL_RDY DC        Calibration Ready
//[1]        R/W                 DC_CALEN             DC Calibration Enable
//[0]        R/W                 DC_CALMD             DC Calibration Mode
//                                                   Mode         Type
//                                                    0          minimum
//                                                    1          average

#define  ADC_Gain_ReadBack_REG           0x0E
#define  ADC_Gain_ReadBack_REG_DEFAULT   0x00
#define  ADC_Gain_ReadBack               0x00


//  ADC Power Down Control

//Bit              Access           Symbol         Description
//[7]               R/W             PwDn_SOY       1:for Power down SOY slicer
//[6]               R/W             PD2 (B)        1: Power down
//                                                 0: Power up
//[5]               R/W             PD1 (G)        1: Power down
//                                                 0: Power up
//[4]               R/W             PD0 (R)        1: Power down
//[3:0]             R/W             Reserved                                                0: Power up

#define  ADC_Power_Down_Control_REG           0x0F
#define  ADC_Power_Down_Control_REG_DEFAULT   0x80
#define  ADC_Power_Down_Control               0x00

    //ADC Polarity Control

//Bit        Access             Symbol                  Description
//[7]        RO/WO            HSi_Polarity / HSi_Inv_    When Read: get input HSync polarity
//                                                       When writing, to invert (0) or non-invert (1) input HSync
//[6]        RO/WO            VSi_Polarity / VSi_Inv_    When Read: get input VSync polarity
//                                                       When writing, to invert (0) or non-invert (1) input VSync
//[5] R/W Reserved
//[4] R/W Auto_Polarity Set to 1 for enabling auto-adjusting HSync/VSync polarity.
//[3] R/W Clamp_Polarity Set to 1 for controlling Clamp positive polarity.
//[2] R/W Clamp_Sel_GfbHS Set to 1 to use PLL feedback HSync as clamp reference
//[1] R/W Clamp_Leading Set to 1 to use leading edge of HSync as clamp reference point.
//[0] R/W Clamp_Sel_RGB Clamp control by: 1: RGB/SOY logic, 0: VD logic.


// YPbPr Clamping

#define  ADC_Polarity_Control_REG           0x10
#define  ADC_Polarity_Control_REG_DEFAULT   0xE8
#define  ADC_Polarity_Control               0x00


// define YPbPr clamping control register (R/W)
//   [7:3] reserved
//   [2][1][0] B/G/R clamping mode 0: clmap to ground
//                                              1: clamp to midscale
    #define YPbPr_CLPCTRL_REG		    0x11
	#define YPbPr_CLPCTRL_DEFAULT		0x00
	#define YPbPr_CLPCTRL				0x05

// define analog source MUX selection (R/W)
//   [7:6] reserved
//   [5:4][3:2][1:0] selection for ADC channel 2/1/0, 0: ACB1/AY1/ACR1
//                                                                     1: ACB0/AY0/ACR0
//                                                                     2: ACB2/AY2/ACR2
// 


         //VSync Separation Register
    #define VSync_Separation_REG		    0x13
	#define VSync_Separation_DEFAULT		0x98
	#define VSync_Separation				0x00  
        
         // Sync Routine Control 
    #define Sync_Routine_Control_REG		    0x14
	#define Sync_Routine_Control_DEFAULT		0xD1
	#define Sync_Routine_Control				0x00       
         
         //Line Lock PLL Divider Register 1
    #define Line_Lock_PLL_Divider1_REG		    0x15
	#define Line_Lock_PLL_Divider1_DEFAULT		0x5A
	#define Line_Lock_PLL_Divider1				0x00      
         
         //Line Lock PLL Divider Register 2
    #define Line_Lock_PLL_Divider2_REG		    0x16
	#define Line_Lock_PLL_Divider2_DEFAULT		0xC3
	#define Line_Lock_PLL_Divider2				0x00 
     
        //VCO & Charge Pump Register
    #define VCO_Charge_Pump_REG		    0x17
	#define VCO_Charge_Pump_DEFAULT		0x48
	#define VCO_Charge_Pump				0x48    
        
                                                                             
    #define ASRC_MUX_REG				0x18
	#define ASRC_MUX_DEFAULT			0x00
	#define ASRC_MUX					0x20




// define Y/Cb/Cr data switching control
//   [7:6] reserved
//   [5:4][3:2][1:0] selection for Cb(chroma)/Y(com)/Cr(chroma) from
//                         0: ADC Ch0
//                         1: ADC Ch1
//                         2: ADC Ch2
//                         3: ADC Ch2
    #define YCbCr_SW_REG				0x19
	#define YCbCr_SW_DEFAULT			0x07
	#define YCbCr_SW					0x08

// define ADC analog AGC selection (R/W)
//   [7:6] gain modulator 0: Positive gain
//                               1: Positive gain 1x~2x
//                               2: Negative gain 1x~2x
//                               3: Negative gain
//   [5:3] Reserved
//   [2][1][0] Cb/Y/Cr gain mode 0: Statice gain (refer to 0x07~0x09)
//                                           1: Dynamic gain
#define ADC_AGC_SEL_REG				0x1A
	#define ADC_AGC_SEL_DEFAULT			0x87

	#define ADC_AGC_SEL					0x87


// Blank sync level (R/W), 0x1C
//   [7:0] blank sync level
#define BLANK_SYNCLV_REG			0X1C
	#define BLANK_SYNCLV_DEFAULT		0xF0
	#define BLANK_SYNCLV				0xB8

          //ADC Phase Setting Register
    #define ADC_Phase_Setting_REG			0X20
	#define ADC_Phase_Setting_DEFAULT		0x80
	#define ADC_Phase_Setting				0x00

         //ADC Detection Register
    #define ADC_Detection_REG			0X21
	#define ADC_Detection_DEFAULT		0x00
	#define ADC_Detection				0x00
                                          
         //ADC Phase Tracking Register 1        Access: Read Only
    #define ADC_Phase_Tracking1_REG			0X22
	    
        //ADC Phase Tracking Register 2         Access: Read Only
    #define ADC_Phase_Tracking2_REG			0X23     
         
       //ADC Phase Tracking Register 3 
    #define ADC_Phase_Tracking3_REG			0X24
    
       //Boundary Control Register
    #define ADC_Boundary_Control1_REG			0X26
	#define ADC_Boundary_Control1_DEFAULT		0x04
	#define ADC_Boundary_Control1				0x00
    
       //Boundary Control Register
    #define ADC_Boundary_Control2_REG			0X27
	#define ADC_Boundary_Control2_DEFAULT		0x40
	#define ADC_Boundary_Control2				0x00
      
      //Boundary Left LSB Register           Access: Read Only
    #define ADC_Boundary_Left_LSB_REG			0X28
	
      //Boundary Left MSB Register           Access: Read Only
    #define ADC_Boundary_Left_MSB_REG			0X29
      
       //Boundary Right LSB Register           Access: Read Only
    #define ADC_Boundary_Right_LSB_REG			0X2A
	
      //Boundary Right MSB Register           Access: Read Only
    #define ADC_Boundary_Right_MSB_REG			0X2B
      
      //Boundary Top LSB Register             Access: Read Only
    #define ADC_Boundary_Top_LSB_REG			0X2C 
      
      //Boundary Top MSB Register             Access: Read Only
    #define ADC_Boundary_Top_MSB_REG			0X2D 
       
       //Boundary Bottom LSB Register             Access: Read Only
    #define ADC_Boundary_Bottom_LSB_REG			0X2E
      
      //Boundary Bottom MSB Register             Access: Read Only
    #define ADC_Boundary_Bottom_MSB_REG			0X2F 
    
          
          
          //Input Timing Register Set
    
      
// De-Interlaced process & vertical shadow control register (R/W),0x30
//   [7] 1: enable CbCr interpolation, 0: disable
//   [6] reserved
//   [5] VST_CHGSEL(?)
//   [4] Interrupt polarity 1: positive
//                                     0: negative
//   [3] capture size for scaler 1: Hsize and Vsize are assigned by 0x54~0x57
//                                            0: size assigned by input sources
//   [2] ENQKHS, set 0 for normal operation
//   [1] 1: interlaced video
//         0: non-interlaced video

#define DITLC_VSHDW_REG				0x30
	#define DITLC_VSHDW_DEFAULT		0x82
	#define DITLC_VSHDW					0x82



    //Source Select Register
//Bit                Access               Symbol              Description
//[7]                  RO                 ITLCFLM             Indicates incoming video signal is interlaced if get 1
//[6:4]                R/W                VIP_Sel[2:0]        Select the digital input source (VIP: Video Input):
//                                                           000: A656
//                                                            001: B656
//                                                            010: L601_8bits
//                                                            011: L601_16bits
//                                                            100: Reserved
//                                                            101: RGB565
//                                                            110: RGB666
//                                                            111: RGB888
//[3:2]               R/W                 InSource_Sel[1:0]   Select the input source:
//                                                            00: Digital VIP input
//                                                            01: select VD input (CVBS, S-Video, YPbPr)
//                                                            10: Select ADC RGB, SOY(YPbPr)
//                                                            11: Reserved
//[1]                 RO                   Reserved
//[0]                 RO                    VBI_Field         Current VBI field information   

    #define Source_Select_REG				    0x31
	#define Source_Select_DEFAULT		        0x40
	#define Source_Select_CVBS_SVideo_YPbPr	    0xC5
    #define Source_Select_RGB_SOY_YPbPr			0xC9

    // Interrupt Status Register
//Bit                Access            Symbol            Description
//[7:0]              RO/W1C            INTSTS            Read to get interrupt trigger source, Write 1 to clear it.
//                                                       [7]: IR packet received
//                                                       [6]: VBI packet is valid for processing
//                                                       [5]: Every VSync Leading Edge
//                                                       [4]: Timer time out
//                                                       [3]: HSync Timing Changed
//                                                       [2]: VSync Timing Changed
//                                                       [1]: Lost HSync
//                                                       [0]: Lost VSync   
 
  #define Interrupt_Status_REG			0x32
	#define Interrupt_Status_DEFAULT		0x00
	#define Interrupt_Status				0xFF


    // Interrupt Mask Register
   
//Bit            Access          Symbol          Description
//[7:0]          R/W             INTMASK         Set to 1 for masking relative interrupt trigger source:
//                                               [7]: IR packet received
//                                               [6]: VBI packet is valid for processing
//                                               [5]: Every VSync Leading Edge
//                                               [4]: Timer time out
//                                               [3]: HSync Timing Changed
//                                               [2]: VSync Timing Changed
//                                               [1]: Lost HSync
//                                               [0]: Lost VSync
    
    #define Interrupt_Mask_REG			0x33
	#define Interrupt_Mask_DEFAULT		0xFF
	#define Interrupt_Mask				0xFF

    //Interrupt Status/Mask 2 Register
    
//Bit     Access            Symbol                   Description
//[7]     RO                Reserved
//[6]     R/W         Mask_ ShortVS_FreeRun          Set to 1 for masking interrupt trigger source of ShortVS_FreeRun_Trig
//[5]     RO          Mask TP_Move                   Set to 1 for masking interrupt trigger source of TouchPanel Moving
//[4]     RO                Reserved
//[3]     RO                Reserved
//[2]   RO/W1C              ShortVS_FreeRun_Trig     Read to get ShortVS interrupt status, Write 1 to clear it
//[1]   RO/W1C              TouchPanel_Move          Read to get TP_Move interrupt status, Write 1 to clear it
//[0]   RO                  SARn_Toggle              Read to get SARn_Toggle interrupt status
	#define Interrupt_Status_Mask_2_REG			0x34
	#define Interrupt_Status_Mask_2_DEFAULT		0x60
	#define Interrupt_Status_Mask_2				0x60
    
     // 1ms Timer LSB Register
    #define ms_Timer_LSB_REG			0x35
	#define ms_Timer_LSB_DEFAULT		0xBC
	#define ms_Timer_LSB				0xBC
    
      // 1ms Timer MSB Register
    #define ms_Timer_MSB_REG			0x36
	#define ms_Timer_MSB_DEFAULT		0x34
	#define ms_Timer_MSB				0x34
    
      // VSYNC Missing Counter Register
     #define VSYNC_Missing_Counter_REG			0x37
	#define VSYNC_Missing_Counter_DEFAULT		0x40
	#define VSYNC_Missing_Counter				0x40
    
       
    
// lower 8-bit HSYNC missing counter register (R/W), 0x38
//   [7:0] 
#define HSYNC_MISSCNT_L_REG			0x38
	#define HSYNC_MISSCNT_L_DEFAULT		0x00
	#define HSYNC_MISSCNT_L					0x50

// upper 8-bit HSYNC missing counter register (R/W), 0x39
//   [7:0] 
#define HSYNC_MISSCNT_H_REG			0x39
	#define HSYNC_MISSCNT_H_DEFAULT		0x10
	#define HSYNC_MISSCNT_H					0x00


// VSYNC delta difference result register (R/W), 0x3A
//   [7:0] 
#define VSYNC_DLT_REG				0x3A
	#define VSYNC_DLT_DEFAULT			0x00
	#define VSYNC_DLT					0x20


// HSYNC delta difference result register (R/W), 0x3B
//   [7:0] 
#define HSYNC_DLT_REG				0x3B
	#define HSYNC_DLT_DEFAULT			0x00
	#define HSYNC_DLT					0x03

    // VD/656 Left Border Crop Register
    #define VD_656_Left_Border_Crop_REG				0x3C
	#define VD_656_Left_Border_Crop_DEFAULT			0x00
	#define VD_656_Left_Border_Crop					0x00

    // VD/656 VSync Offset Register
    #define VD_656_VSync_Offset_REG				0x3D
	#define VD_656_VSync_Offset_DEFAULT			0x00
	#define VD_656_VSync_Offset					0x00

     // VD/656 Left Border Crop Register
    #define VD_656_Left_Border_Crop1_REG				0x3E
	#define VD_656_Left_Border_Crop1_DEFAULT			0x00
	#define VD_656_Left_Border_Crop1					0x00

     //Input Sync Signal Detection Register
    #define Input_Sync_Signal_Detection_REG				0x3F
	#define Input_Sync_Signal_Detection_DEFAULT			0x00
	#define Input_Sync_Signal_Detection					0x00


// Left border croping, 0x40
//	[7:6] reserved
//	[5:0] remove pixels on left border
#define LBORDER_CROP_REG			0x40
	#define LBORDER_CROP_DEFAULT		0x00
	#define LBORDER_CROP				0x18

    //ADC HSync Offset LSB Register
    #define ADC_HSync_Offset_LSB_REG			0x41
	#define ADC_HSync_Offset_LSB_DEFAULT		0x02
	#define ADC_HSync_Offset_LSB				0x02

    //ADC HSync Offset MSB Register
    #define ADC_HSync_Offset_MSB_REG			0x42
	#define ADC_HSync_Offset_MSB_DEFAULT		0x00
	#define ADC_HSync_Offset_MSB				0x00

    //ADC VSync Offset LSB Register
    #define ADC_VSync_Offset_LSB_REG			0x43
	#define ADC_VSync_Offset_LSB_DEFAULT		0x01
	#define ADC_VSync_Offset_LSB				0x01

    //ADC VSync Offset MSB Register
    #define ADC_VSync_Offset_MSB_REG			0x44
	#define ADC_VSync_Offset_MSB_DEFAULT		0x00
	#define ADC_VSync_Offset_MSB				0x00

    //ADC HSync Offset Pulse Width Register
    #define ADC_HSync_Offset_Pulse_Width_REG			0x45
	#define ADC_HSync_Offset_Pulse_Width_DEFAULT		0x10
	#define ADC_HSync_Offset_Pulse_Width				0x10

    //ADC VSync Offset Pulse Width Register
    #define ADC_VSync_Offset_Pulse_Width_REG			0x46
	#define ADC_VSync_Offset_Pulse_Width_DEFAULT		0x01
	#define ADC_VSync_Offset_Pulse_Width				0x01

    //ADC Capture Control Register
    #define ADC_Capture_Control_REG			    0x47
	#define ADC_Capture_Control_DEFAULT		    0x00
	#define ADC_Capture_Control	     			0x00

    //ADC Capture HSize LSB Register
    #define ADC_Capture_HSize_LSB_REG			    0x48
	#define ADC_Capture_HSize_LSB_DEFAULT		    0x00
	#define ADC_Capture_HSize_LSB			    	0x00

    //ADC Capture HSize MSB Register
    #define ADC_Capture_HSize_MSB_REG			    0x49
	#define ADC_Capture_HSize_MSB_DEFAULT		    0x02
	#define ADC_Capture_HSize_MSB			    	0x02

    //ADC Capture VSize LSB Register
    #define ADC_Capture_VSize_LSB_REG			    0x4A
	#define ADC_Capture_VSize_LSB_DEFAULT		    0xE0
	#define ADC_Capture_VSize_LSB			    	0xE0

    //ADC Capture VSize MSB Register
    #define ADC_Capture_VSize_MSB_REG			    0x4B
	#define ADC_Capture_VSize_MSB_DEFAULT		    0x01
	#define ADC_Capture_VSize_MSB			    	0x01

    //ADC Capture HSync Back Porch LSB Register
    #define ADC_Capture_HSync_Back_Porch_LSB_REG			    0x4C
	#define ADC_Capture_HSync_Back_Porch_LSB_DEFAULT		    0x10
	#define ADC_Capture_HSync_Back_Porch_LSB			    	0x10

    //ADC Capture HSync Back Porch MSB Register
    #define ADC_Capture_HSync_Back_Porch_MSB_REG			    0x4D
	#define ADC_Capture_HSync_Back_Porch_MSB_DEFAULT		    0x00
	#define ADC_Capture_HSync_Back_Porch_MSB			    	0x00

    //ADC Capture VSync Back Porch LSB Register
    #define ADC_Capture_VSync_Back_Porch_LSB_REG			    0x4E
	#define ADC_Capture_VSync_Back_Porch_LSB_DEFAULT		    0x05
	#define ADC_Capture_VSync_Back_Porch_LSB			    	0x05

    //ADC Capture VSync Back Porch MSB Register
    #define ADC_Capture_VSync_Back_Porch_MSB_REG			    0x4F
	#define ADC_Capture_VSync_Back_Porch_MSB_DEFAULT		    0x00
	#define ADC_Capture_VSync_Back_Porch_MSB			    	0x00

// VSYNC timing measurement register. 0x50
//   [7] reserved
//   [6] register 0x5C/0x5D can be HS pulse width or hsync period
//         0: period in # of pixel clock
//         1: hsync pulse width in # of pixel clock
//   [5] (R)when [4]=1, a whole frame time can be obtained through XCLK counting
//                             see register 0x51~0x53
//         after this bit read back as 1, then clear [4] first before reading 0x51~0x53
//   [4] when input Vsync changes, enable this bit to start measurement on Vsync using XCLK
//   [3:0] reserved
#define VSYNC_TIME_MEA_REG			0x50
	#define VSYNC_TIME_MEA_DEFAULT 		0x00
	#define VSYNC_TIME_MEA 				0x06

   // VSync Period Measurement L Register
    #define VSync_Period_Measurement_L_REG			0x51
	#define VSync_Period_Measurement_L_DEFAULT 		0x00
	#define VSync_Period_Measurement_L 				0x00

   // VSync Period Measurement M Register
    #define VSync_Period_Measurement_M_REG			0x52
	#define VSync_Period_Measurement_M_DEFAULT 		0x00
	#define VSync_Period_Measurement_M 				0x00

    // VSync Period Measurement H Register
    #define VSync_Period_Measurement_H_REG			0x53
	#define VSync_Period_Measurement_H_DEFAULT 		0x00
	#define VSync_Period_Measurement_H 				0x00

    //Input HSize LSB Register
    #define Input_HSize_LSB_REG			    0x54
	#define Input_HSize_LSB_DEFAULT 		0x00
	#define Input_HSize_LSB 				0x00

    //Input HSize MSB Register
    #define Input_HSize_MSB_REG			    0x55
	#define Input_HSize_MSB_DEFAULT 		0x00
	#define Input_HSize_MSB 				0x00

    //Input VSize LSB Register
    #define Input_VSize_LSB_REG			    0x56
	#define Input_VSize_LSB_DEFAULT 		0x00
	#define Input_VSize_LSB 				0x00

    //Input VSize MSB Register
    #define Input_VSize_MSB_REG			    0x57
	#define Input_VSize_MSB_DEFAULT 		0x00
	#define Input_VSize_MSB 				0x00

    //HSync Period LSB Register
    #define HSync_Period_LSB_REG		    0x58
	#define HSync_Period_LSB_DEFAULT 		0x00
	#define HSync_Period_LSB 				0x00
    
    //HSync Period MSB Register
    #define HSync_Period_MSB_REG			0x59
	#define HSync_Period_MSB_DEFAULT 		0x00
	#define HSync_Period_MSB 				0x00

    //VSync Period LSB Register
    #define VSync_Period_LSB_REG		    0x5A
	#define VSync_Period_LSB_DEFAULT 		0xFF
	#define VSync_Period_LSB 				0xFF
    
    //VSync Period MSB Register
    #define VSync_Period_MSB_REG			0x5B
	#define VSync_Period_MSB_DEFAULT 		0x00
	#define VSync_Period_MSB 				0x00

    // HSync Pulse Width LSB Register
    #define HSync_Pulse_Width_LSB_REG			0x5C
	#define HSync_Pulse_Width_LSB_DEFAULT 		0x00
	#define HSync_Pulse_Width_LSB 				0x00

    // HSync Pulse Width MSB Register
    #define HSync_Pulse_Width_MSB_REG			0x5D
	#define HSync_Pulse_Width_MSB_DEFAULT 		0x00
	#define HSync_Pulse_Width_MSB 				0x00

    // VSync Pulse Width LSB Register
    #define VSync_Pulse_Width_LSB_REG			0x5E
	#define VSync_Pulse_Width_LSB_DEFAULT 		0x00
	#define VSync_Pulse_Width_LSB 				0x00

    // VSync Pulse Width MSB Register
    #define VSync_Pulse_Width_MSB_REG			0x5F
	#define VSync_Pulse_Width_MSB_DEFAULT 		0x00
	#define VSync_Pulse_Width_MSB 				0x00

// Bandwidth of Digital Color Transient Improvement, 0x60
//   [7:1] reserved
//   [0] 0: high bandwidth
//        1: low bandwidth
#define DCTI_BW_REG					0x60
	#define DCTI_BW_DEFAULT 			0x00

	#define DCTI_BW		 				0x01


// Luma Peaking control, also refer to P2_80h, 0x61
//   [7] peaking EN
//   [6] reserved
//   [5:0] peaking Co
#define LUMA_PKCTRL_REG				0x61
	#define LUMA_PKCTRL_DEFAULT 		0x08
	#define LUMA_PKCTRL		 			0x8F

// Bandpass peaking coef, 0x62
//   [7:5] reserved
//   [4:0] bandpass coefficient
#define BP_PKCOEF_REG				0x62
	#define BP_PKCOEF_DEFAULT 			0x04
	#define BP_PKCOEF		 			0x0F

// Highpass peaking coef, 0x63
//   [7:5] reserved
//   [4:0] highpass coefficient
#define HP_PKCOEF_REG				0x63
	#define HP_PKCOEF_DEFAULT 			0x04
	#define HP_PKCOEF		 			0x0F

// Lowpass peaking coef, 0x64
//   [7:5] reserved
//   [4:0] lowpass coefficient
#define LP_PKCOEF_REG				0x64
	#define LP_PKCOEF_DEFAULT 			0x02
	#define LP_PKCOEF		 			0x04

// Gain and coring of DLTI, 0x65
//   [7:5] gain
//   [4:0] coring
#define DLTI_GAINCO_REG				0x65
	#define DLTI_GAINCO_DEFAULT 			0x08
	#define DLTI_GAINCO		 			0x08

// Gain and coring of DCTI, 0x66
//   [7:5] gain
//   [4:0] coring
#define DCTI_GAINCO_REG				0x66
	#define DCTI_GAINCO_DEFAULT 		0x08
	#define DCTI_GAINCO		 			0x88

    // Cb/Cr Delay control
    #define CbCr_Delay_control_REG				0x67
	#define CbCr_Delay_control_DEFAULT 		    0x1E
	#define CbCr_Delay_control		 			0x1E

//Constrast adjust (on output side, for user), 0x68
//   [7:0] constrast level
#define OP_CONST_REG				0x68
	#define OP_CONST_DEFAULT 			0x80
//Brightness adjust (on output side, for user), 0x69
//   [7:0] Brightness level
#define OP_BRIGHT_REG				0x69
	#define OP_BRIGHT_DEFAULT 			0x80
//Hue sin adjust , 0x6A
//   [7] sign bit
//   [6:0] Hue sin value, ( represent -1~1)
#define OP_HUESIN_REG				0x6A
	#define OP_HUESIN_DEFAULT 			0x00
//Hue cos adjust , 0x6B
//   [7] sign bit
//   [6:0] Hue cos value, ( represent -1~1)
#define OP_HUECOS_REG				0x6B
	#define OP_HUECOS_DEFAULT 			0x7F
//Chroma saturation adjust (on output side, for user), 0x6C
//   [7:0] constrast level
#define OP_SAT_REG					0x6C
	#define OP_SAT_DEFAULT 				0x80
	
	#define OP_CONST		 			0x80
	#define OP_BRIGHT		 			0x80
	#define OP_SAT		 				0x80
	#define OP_HUESIN		 			0x00
	#define OP_HUECOS		 			0x7F

   //White Level Expansion Threshold Register
    #define White_Level_Expansion_Threshold_REG				0x6D
	#define White_Level_Expansion_Threshold_DEFAULT 	    0xEB
	#define White_Level_Expansion_Threshold		 			0xEB

   // Black Level Expansion Threshold Register
    #define Black_Level_Expansion_Threshold_REG				0x6E
	#define Black_Level_Expansion_Threshold_DEFAULT 	    0x10
	#define Black_Level_Expansion_Threshold		 			0x10

   // VIP Black level Expansion Gain / Offset Control Register
    #define VIP_Black_level_Expansion_Gain_Offset_Control_REG				0x6F
	#define VIP_Black_level_Expansion_Gain_Offset_Control_DEFAULT 	        0x00
	#define VIP_Black_level_Expansion_Gain_Offset_Control	 			    0x00

// Scaling general control register, 0x70
//   [7:6]
//   [5] reverse input odd field control for intrafield scaling, 
//         only take action when ITLCPRO(P0_30[1]) set to 1
//   [4] software need to turn this bit on when the freq of i/p clock is higher than o/p pixel clock
//   [3] remove 2D scaling for 2 pixels width chess board boundary effect
//   [2] enable 2D scaler
//   [1:0] reset coef table 01b: reset write pointer to 0x00
//                                     10b: reset write pointer to 0x80
#define SCALE_GENCTRL_REG			0x70
	#define SCALE_GENCTRL_DEFAULT		0x40 
	#define SCALE_GENCTRL				0x90

// scaling coefficient data port register, 0x71
#define SCALE_COEFDATA_REG			0x71

// Horizontal/Vertical scale step LSB/MSB register, 0x72~0x75
// value= (output size/input size) * 2^15
// 0~0x8000 scale up, 0x8001~0xFFFF scale down
// MUST WRITE 0x75 TO MAKE IT WORK
#define HSCALE_STP_L_REG			0x72
#define HSCALE_STP_H_REG			0x73
#define VSCALE_STP_L_REG			0x74
#define VSCALE_STP_H_REG			0x75
	#define HSCALE_STP_L				0xE0	// 0x33 for T100 demo
	#define HSCALE_STP_H				0xB7 //0x73 for T100 demo
	#define VSCALE_STP_L				0x00 //
	#define VSCALE_STP_H				0x84 //0x40 for T100 demo
#define USE_PRESET_SCALE		1

// Horizontal aspect ratio register, 0x76, 0x77
//   [7:0] LSB
//   [7] enable aspect ratio 1: enable, 0: disable
//   [6] 1: enlarge, 0: compact (center area)
//   [5:0] MSB
#define HASPR_L_REG					0x76
#define HASPR_H_REG					0x77


     //Low Pass Filter Register
    #define Low_Pass_Filter_REG				    0x78
	#define Low_Pass_Filter_DEFAULT 	        0x00
	#define Low_Pass_Filter	     	            0x00
    
    // High Boost Filter Register
    #define High_Boost_Filter_REG			    0x79
	#define High_Boost_Filter_DEFAULT 	        0x00
	#define High_Boost_Filter	     	        0x00
    
    // High Boost Register
    #define High_Boost_REG			    0x7A
	#define High_Boost_DEFAULT 	        0x00
	#define High_Boost	     	        0x00
    
    //Motion Register
    #define Motion_REG			    0x7C
	#define Motion_DEFAULT 	        0x08
	#define Motion	     	        0x08

    //Frame Color (Luma-Y) in Scaler Register
    #define Frame_Color_Luma_Y_in_Scaler_REG			    0x7D
	#define Frame_Color_Luma_Y_in_Scaler_DEFAULT 	        0x10
	#define Frame_Color_Luma_Y_in_Scaler	     	        0x10

    //Frame Color (Luma-U) in Scaler Register
    #define Frame_Color_Luma_U_in_Scaler_REG			    0x7E
	#define Frame_Color_Luma_U_in_Scaler_DEFAULT 	        0x80
	#define Frame_Color_Luma_U_in_Scaler	     	        0x80

    //Frame Color (Luma-V) in Scaler Register
    #define Frame_Color_Luma_V_in_Scaler_REG			    0x7F
	#define Frame_Color_Luma_V_in_Scaler_DEFAULT 	        0x80
	#define Frame_Color_Luma_V_in_Scaler	     	        0x80


// Line buffer configuration LSB/MSB register, 0x84, 0x85
//   [7:0]
//   [15:8]
//    this register can cause a time delay in XCLK count between the
//    leading edge of input Vsync and leading edge of output Vsync
#define LINE_BUF_L_REG				0x84
#define LINE_BUF_H_REG				0x85
	#define LINE_BUF_L					0x30
	#define LINE_BUF_H					0x15
#define USE_PRESET_LINE_BUF		1


     //Output VSync Front Porch Remapping Register
    #define Output_VSync_Front_Porch_Remapping_REG			    0x87
	#define Output_VSync_Front_Porch_Remapping_DEFAULT 	        0x00
	#define Output_VSync_Front_Porch_Remapping	     	        0x00

    // Left Display Border Configuration LSB Register
    #define Left_Display_Border_Configuration_LSB_REG			    0x88
	#define Left_Display_Border_Configuration_LSB_DEFAULT 	        0x00
	#define Left_Display_Border_Configuration_LSB	     	        0x00

     // Left Display Border Configuration MSB Register
    #define Left_Display_Border_Configuration_MSB_REG			    0x89
	#define Left_Display_Border_Configuration_MSB_DEFAULT 	        0x00
	#define Left_Display_Border_Configuration_MSB	     	        0x00

   // Right Display Border Configuration LSB Register
    #define Right_Display_Border_Configuration_LSB_REG			    0x8A
	#define Right_Display_Border_Configuration_LSB_DEFAULT 	        0x00
	#define Right_Display_Border_Configuration_LSB	     	        0x00

     // Right Display Border Configuration MSB Register
    #define Right_Display_Border_Configuration_MSB_REG			    0x8B
	#define Right_Display_Border_Configuration_MSB_DEFAULT 	        0x00
	#define Right_Display_Border_Configuration_MSB	     	        0x00

   // Top Display Border Configuration LSB Register
    #define Top_Display_Border_Configuration_LSB_REG			    0x8C
	#define Top_Display_Border_Configuration_LSB_DEFAULT 	        0x00
	#define Top_Display_Border_Configuration_LSB	     	        0x00

     // Top Display Border Configuration MSB Register
    #define Top_Display_Border_Configuration_MSB_REG			    0x8D
	#define Top_Display_Border_Configuration_MSB_DEFAULT 	        0x00
	#define Top_Display_Border_Configuration_MSB	     	        0x00

   
   // Bottom Display Border Configuration LSB Register
    #define Bottom_Display_Border_Configuration_LSB_REG			    0x8E
	#define Bottom_Display_Border_Configuration_LSB_DEFAULT         0x00
	#define Bottom_Display_Border_Configuration_LSB	     	        0x00

    // Bottom Display Border Configuration MSB Register
    #define Bottom_Display_Border_Configuration_MSB_REG			    0x8F
	#define Bottom_Display_Border_Configuration_MSB_DEFAULT 	    0x00
	#define Bottom_Display_Border_Configuration_MSB	     	        0x00


// Image function control register, 0x90
//   [7:6] Gamma table select 11: Gamma table R
//                                            10: Gamma table G
//                                            01: Gamma table B
//                                            00: All 3
//   [5:3] reserved
//   [2] enable CSC(color space conversion), 1: enable (default)
//   [1] enable Gamma
//   [0] enable Dithering
#define IMG_FUNCTRL_REG				0x90
	#define IMG_FUNCTRL_DEFAULT			0x04

	#define IMG_FUNCTRL					0x04


// Built-in pattern generator control register
//   [7] enable frame backgroud color, refer of 0x9D~0x9F
//   [6] enable pattern generator shows 9 patterns sequentially
//         [7:6] 00: normal color
//                  01: normal color
//                  10: still pattern
//                  11: motion patterns
//   [5] 1: indicate 8-bit patterns
//         0: indicate 6-bit patterns
//   [4] reserved
//   [3:0]
#define BTIN_PATTERN_REG			0x91
	#define BTIN_PATTERN_DEFAULT		0x04
	#define BTIN_PATTERN				0x04


     //GAMMA Table Address Port Register
    #define GAMMA_Table_Address_Port_REG			0x93
	#define GAMMA_Table_Address_Port_DEFAULT		0x00
	#define GAMMA_Table_Address_Port				0x00

     //GAMMA Table Write Data Port Register
    #define GAMMA_Table_Write_Data_Port_REG			0x94
	#define GAMMA_Table_Write_Data_Port_DEFAULT		0x00
	#define GAMMA_Table_Write_Data_Port				0x00

	
// define CSC Y coef (R/W), 0x97
// [7:0] 1.7-bit fixed point ( int*2^7 + frac*2^7)
#define CSC_YCOEF_REG				0x97
	#define CSC_YCOEF_DEFAULT			0x95 //=1.164
	#define CSC_YCOEF					0x95 //=1.164
// define CSC Red coef of Cr (R/W)
// [7:0] 1.7-bit fixed point ( int*2^7 + frac*2^7)
#define CSC_CrRCOEF_REG				0x98
	#define CSC_CrRCOEF_DEFAULT			0xA6 //=1.297?
	#define CSC_CrRCOEF					0xCC //=1.594

   //CC/Ext_OSD Mixer Interface Register
    #define CC_Ext_OSD_Mixer_Interface_REG			0x99
	#define CC_Ext_OSD_Mixer_Interface_DEFAULT		0x02
	#define CC_Ext_OSD_Mixer_Interface				0x02


    // CC/Ext_OSD Mixer Control Register
    #define CC_Ext_OSD_Mixer_Control_REG			0x9A
	#define CC_Ext_OSD_Mixer_Control_DEFAULT		0x40
	#define CC_Ext_OSD_Mixer_Control				0x40

   //CC/Ext_OSD Mixer LUT Data Port Register
    #define CC_Ext_OSD_Mixer_LUT_Data_Port_REG			0x9B
	#define CC_Ext_OSD_Mixer_LUT_Data_Port_DEFAULT		0x00
	#define CC_Ext_OSD_Mixer_LUT_Data_Port				0x00

// Pattern color gradient & dithering mode register, 0x9C
//   [7:4] when P0_09[7:6] set to 11. this bit may set color gradient at pattern 2,3,4,5
//   [3:2] reserved
//   [1:0] dithering mode. enabled by P0_09[0]
//                                      00: 4-bit output
//                                      01: 5-bit output
//                                      10: 6-bit output
//                                      11: 7-bit output
#define PATTERN_GRA_DITH_REG		0x9C
	#define PATTERN_GRA_DITH_DEFAULT	0x00
	#define PATTERN_GRA_DITH			0x02


     // Frame Color Red Configuration Register
    #define Frame_Color_Red_Configuration_REG		0x9D
	#define Frame_Color_Red_Configuration_DEFAULT	0x00
	#define Frame_Color_Red_Configuration			0x00

     // Frame Color Green Configuration Register
    #define Frame_Color_Green_Configuration_REG		0x9E
	#define Frame_Color_Green_Configuration_DEFAULT	0x00
	#define Frame_Color_Green_Configuration			0x00

    // Frame Color Red Configuration Register
    #define Frame_Color_blue_Configuration_REG		0x9F
	#define Frame_Color_blue_Configuration_DEFAULT	0x00
	#define Frame_Color_blue_Configuration			0x00

// output timing control
// Display window horizontal/vertical start LSB/MSB register, 0xB0~0xB3
//   [7:0] LSB
//   [7:4] reserved
//   [3:0] MSB
//	when PAUTO_SYNC is enabled, DWVS is set by auto-detection (default ?)
//
// Display window horizontal/vertical width(size) LSB/MSB register, 0xB4~0xB7
//   [7:0] LSB
//   [7:4] reserved
//   [3:0] MSB
//
// Display panel horizontal/vertical total dots per scan line LSB/MSB register,0xB8~0xBB
//   [7:0] LSB
//   [7:4] reserved
//   [3:0] MSB
//
// Display panel Hsync/Vsync width LSB/MSB register, 0xBC~0xBF
//   [7:0] LSB
//   [7:4] reserved
//   [3:0] MSB
//
#define DWHS_L_REG        			0xB0
#define DWHS_H_REG        			0xB1
#define DWVS_L_REG        			0xB2
#define DWVS_H_REG       			0xB3
#define DWHSZ_L_REG        			0xB4
#define DWHSZ_H_REG        			0xB5
#define DWVSZ_L_REG        			0xB6
#define DWVSZ_H_REG       			0xB7
#define PH_TOT_L_REG      			0xB8
#define PH_TOT_H_REG      			0xB9
#define PV_TOT_L_REG      			0xBA
#define PV_TOT_H_REG      			0xBB
#define PH_PW_L_REG       			0xBC
#define PH_PW_H_REG       			0xBD
#define PV_PW_L_REG       			0xBE
#define PV_PW_H_REG       			0xBF

	#define DWHS_L        				0x20
	#define DWHS_H        				0x00
	#define DWVS_L        				0x0D
	#define DWVS_H        				0x00
	#define DWHSZ_L        				(H_Size&0xFF)
	#define DWHSZ_H        				(H_Size>>8)
	#define DWVSZ_L        				(V_Size&0xFF)
	#define DWVSZ_H        				(V_Size>>8)
	#define PH_TOT_L      				0x88
	#define PH_TOT_H      				0x02
	#define PV_TOT_L      				0x04
	#define PV_TOT_H      				0x01
	#define PH_PW_L       				0x10
	#define PH_PW_H       				0x00
	#define PV_PW_L       				0x03
	#define PV_PW_H       				0x00
#define USE_PRESET_OPTIMING		1

// Panel output signal control 3 register, 0xC1
//	[7:4] reserved (?)
//	[3] DCLK polarity.	0: Normal(default), 1: inverted
//	[2] ODCK internal delay(LVDS mode).	0: National standard(default)
//									1: Korean/Non-standard
//	[1:0] reserved
#define POUT_CTRL3_REG				0xC1
	#define POUT_CTRL3_DEFAULT			0x01
	#define POUT_CTRL3					0xC8
	

// Panel Vsync frame delay control register, 0xC2
//	[7] convert interlaced input timing for output timing generation
//	[6:5] reserved
//	[4]	1: block input Vsync triggering on output Vsync
//		0: allow input Vsync to trigger output Vsync
//	[3]	0: short line, i.e., last Hsync is less than 1.0 line
//		1: long line, i.e., last Hsync is greater than 1.0 line
//	[2] Save recovery mode
//	[1] ignore the input Vsync. this can be used for output free run when input Vsync is not available
//	[0] reserved
#define POUT_VSYNC_CTRL_REG			0xC2
	#define POUT_VSYNC_CTRL_DEFAULT		0x00

	#define POUT_VSYNC_CTRL				0x12


// Output PLL divider 1 register, 0xC8
//	[7] reserved
//	[6:0] PLL feedback divider. default=124(0x7C)
//
// Output PLL divider 2 register, 0xC9
//	[7:5] reserved
//	[4:0] PLL input divider. default=27(0x1B)
//
// Output PLL divider 3 register, 0xCA
//	[7:6] PLL MUX function select	00: PLLCLK
//							01: Bypass PLL
//							10: Keep High
//							11: Keep high
//	[5] ?
//	[4] ?
//	[3:2] reserved
//	[1:0] PLL output divider. default=1
#define PLLDIV_FB_REG				0xC8
	#define PLLDIV_FB_DEFAULT			0x7C
#define PLLDIV_IP_REG				0xC9
	#define PLLDIV_IP_DEFAULT			0x1B
#define PLLDIV_OP_REG				0xCA
	#define PLLDIV_OP_DEFAULT			0x01

	#define PLLDIV_FB					DFDIV_40
	#define PLLDIV_IP					DIDIV

	#define PLLDIV_OP					DODIV

// Horizontal/Vertical main display start, 0xD8~0xDB
//	[7:0] LSB
//	[7:4] reserved
//	[3:0] MSB
#define HMDISP_STR_L_REG			0xD8
	#define HMDISP_STR_L_DEFAULT		0x00
#define HMDISP_STR_H_REG			0xD9
	#define HMDISP_STR_H_DEFAULT		0x00
#define VMDISP_STR_L_REG			0xDA
	#define VMDISP_STR_L_DEFAULT		0x00
#define VMDISP_STR_H_REG			0xDB
	#define VMDISP_STR_H_DEFAULT		0x00

	#define HMDISP_STR_L				0x00
	#define HMDISP_STR_H				0x00
	#define VMDISP_STR_L				0x00
	#define VMDISP_STR_H				0x00
	
// Horizontal/Vertical main display size, 0xDC~0xDF
//	[7:0] LSB
//	[7:4] reserved
//	[3:0] MSB
#define HMDISP_SIZE_L_REG			0xDC
	#define HMDISP_SIZE_L_DEFAULT		0x00
#define HMDISP_SIZE_H_REG			0xDD
	#define HMDISP_SIZE_H_DEFAULT		0x05
#define VMDISP_SIZE_L_REG			0xDE
	#define VMDISP_SIZE_L_DEFAULT		0x00
#define VMDISP_SIZE_H_REG			0xDF
	#define VMDISP_SIZE_H_DEFAULT		0x04

	#define HMDISP_SIZE_L				(H_Size&0xFF)
	#define HMDISP_SIZE_H				(H_Size>>8)
	#define VMDISP_SIZE_L				(V_Size&0xFF)
	#define VMDISP_SIZE_H				(V_Size>>8)

// define power management control register (R/W), 0xE0
// [7] when 0, power down whole chip/pull down pads (default = 1)
// [6] power down mode 0: Whole chip power down
//                               1: Output pads pull down
// [5] power down ADC, low active
// [4] power down comb video decoder, for internal software test, low active
// [3] power down DisplayPLL
// [2] power down MPLL
// [1] reserved
// [0] power down TC interface, low active
//
// Output pin configuration, 0xE1
//	[7:6] Row STV select	00: output both
//						01: output both
//						10: output STV1
//						11: output STV2
//	[5:4] Col STH select		00: output both
//						01: output both
//						10: output STH1
//						11: output STH2
//	[3] up-down selection
//	[2] left-right selection
//	[1:0] reserved
#define PW_MGRCTRL_REG				0xE0
	#define PW_MGRCTRL_DEFAULT			0x1C
#define OPIN_CFG_REG				0xE1
	#define OPIN_CFG_DEFAULT			0x00
#ifdef TCON
	#define PW_MGRCTRL					0x9D
	#define OPIN_CFG					0xF4

#else
	#define PW_MGRCTRL					0x9C
	#define OPIN_CFG					0x00
#endif
	
//-----------------------------------------------------------------------------
//-----------------------------------------------------------------------------
//    Page 2 registers definition
//-----------------------------------------------------------------------------
//-----------------------------------------------------------------------------

// Video source selection of Comb filter, 0x00
//	[7] reserved
//	[6:5] select the number of pixel per scan line
//		00: 858pixels, NTSC, PAL(M)
//		01: 864pixels, PAL(B,D,G,H,I,N,CN), SECAM
//		10: 780pixels, NTSC square pixel, PAL(M) square pixel
//		11: 944pixels, PAL(B,D,G,H,I,N) square pixel
//	[4] select the number of scan lines per frame
//		0: 525 (default)
//		1: 625
//	[3:1] select SDTV video mode
//		000: NTSC (default)
//		001: PAL(I,B,G,H,D,N)
//		010: PAL(M)
//		011: PAL(CN)
//		100: SECAM
//	[0] select input video format
//		0: CVBS composite (default)
//		1: S-Video (separated Y/C)
#define SRCSEL_COMBF_REG			0x00
	#define SRCSEL_COMBF_DEFAULT		0x00
	#define SRCSEL_COMBF				0x00

// Bandwidth control, 0x01
//	[7] invert the select signal for the analog input multiplexer during component video mode
//		0: not inverted(default)
//		1: inverted
//	[6] 	0: S-video or CVBS
//		1: YPbPr component video input
//	[5:4] select luma notch width
//		00: none (default)
//		01: narrow
//		10: medium
//		11: wide
//	[3:2] set the chroma low pass filter to wide or narrow
//		00: narrow (default)
//		01: wide
//		10: extra wide
//		11: extra wide
//	[1] select the burst gate width
//		0: 5 subcarrier clock cycles (default)
//		1: 10 subcarrier clock cycles 
//	[0] enable black level correction for 10 blank-to-blank pedestal
//		0: no pedestal subtraction
//		1: pedestal subtraction (default)
#define BW_CTRL_REG					0x01
	#define BW_CTRL_DEFAULT				0x01
	#define BW_CTRL						0x01
	#define ENYPbPr						0x40

// Y/C AGC enable, 0x02
//	[7] 	0: (default)gain is updated once per line, after DC clamping
//		1: gain is only updated once per field, at the start of vertical blank
//	[6]	1: (default) automatically reduce the gain (set in P2_04) by 25%
//		    when macro-vision encoded signals are detected
//		0: off
//	[5:4]	analog front end DC clamping
//		00: auto (default)
//		01: backporch only
//		10: synctip only
//		11: off
//	[3]	1: (default) enable the digital AGC, used in series with the analog gain
//	[2]	reserved
//	[1]	1: (default) enable the chroma AGC
//		0: the AGC target is used to drive directly the AGC gain
//	[0]	1: (default) enable the luma/composite AGC
//		0: use AGC target (P2_04h) to drive directly the AGC gain
#define YC_AGC_REG					0x02
	#define YC_AGC_DEFAULT				0x4F
	#define YC_AGC						0x4B //not equal to 0x4B, despite of [2] is reserved (?)

// Comb filtering mode, 0x03
//	[7:4]	reserved
//	[3] 	enable the notch-filter at the luma path after the comb filter.
//		This filter can be turned on or off irrespective of the adaptive mode setting
//		0: disable (default),  	1: enable
//	[2:0] select the filter modes for the composite signal's luma(Y) and chroma (C)
//		separation before color demodulation
//		000: (default) fully adaptive comb (2-D adaptive comb)
//		001: vertical adaptive comb (1-D adaptive comb, vertical bomb only)
//		010: 5-tap adaptive comb filter (PAL mode only)
//		011: basic luma notch filter mode (for very noisy and unstable pictures)
//		100: simple 2-tap comb
//		101: simple 3-tap comb
//		110: 5-tap hybrid adaptive comb filter (PAL mode only)
#define COMB_FILTERMODE_REG			0x03
	#define COMB_FILTERMODE_DEFAULT		0x00
	#define COMB_FILTERMODE				0x00
	
// Luma AGC target value, 0x04
//
//	0xDD: NTSC M, PAL M,N
//	0xCD: NTSC J
//	0xDC: PAL B,D,G,H,I, COMB N, SECAM
//	0xA6: NTSC M (macro-vision)
//	0xAE: PAL B,D,G,H,I, COMB N (macro-vision)
#define HAGC_REG						0x04
	#define HAGC_DEFAULT				0xDD
	#define HAGC						0xDD

// Y/C output control, 0x07
//	[7]	reserved
//	[6]	swap Cb/Cr outputs
//		0: don't swap Cb/Cr 
//		1: (default) swap Cb/Cr 
//	[5:4] control the blue screen mode
//		00: disabled
//		01: enabled
//		10: auto (default)
//		11: reserved
//	[3:0] 2's complement number, controls the output delay between luma and chroma.
//		 Negative values shift luma outputs to the left while positive valus shift luma
//		 values to the right. The range is [-5, 7]. Default=000.
#define YC_OPCTRL_REG				0x07
	#define YC_OPCTRL_DEFAULT			0x20
	#define YC_OPCTRL					0x22

// Luma contrast, 0x08   (internal use)
//	
// Luma brightness, 0x09
//	offset by -32
//
// Chroma saturation, 0x0a
//
// Chroma Hue phase, 0x0B
//	2's complement number
//
// Chroma AGC, 0x0C
#define CONTRAST_REG				0x08
	#define CONTRAST_DEFAULT			0x80
#define BRIGHT_REG					0x09
	#define BRIGHT_DEFAULT				0x20
#define SAT_REG						0x0A
	#define SAT_DEFAULT					0x80
#define HUE_REG						0x0B
	#define HUE_DEFAULT					0x00
#define CHROMA_AGC_REG				0x0C
	#define CHROMA_AGC_DEFAULT			0x8A
	
	#define CONTRAST					0x80
#ifdef _640_234  //AT_VGA	
	#define BRIGHT						0x18
#else
	#define BRIGHT						0x20
#endif
	#define SAT							0x80
	#define HUE							0x00
	#define CHROMA_AGC					0x8A

// AGC peak nomial, 0x10
//	[7] reserved
//	[6:0] set the luma peak white detection's AGC nominal peak white value.
//		this value is added to 128 and then the result is multiplied by 4.
//		Default = 0x0A(10d)
#define AGC_PKNO_REG				0x10
	#define AGC_PKNO_DEFAULT			0x0A
	#define AGC_PKNO					0x27

// AGC peak and gate control, 0x11
//	[7]
#define AGC_PKGT_CTRL_REG			0x11
	#define AGC_PKGT_CTRL_DEFAULT		0xB9  

	#define AGC_PKGT_CTRL				0xB9


// Chroma DTO incremental 0, 1, 2, 3, 0x18~0x1B
//	[7]	1: fix chroma DTO at center frequency
//		0: Chroma DTO assigned by registers
//	[6]	reserved
//	[29:0]
#define CHROMA_DTO0_REG				0x18
	#define CHROMA_DTO0_DEFAULT			0x21
#define CHROMA_DTO1_REG				0x19
	#define CHROMA_DTO1_DEFAULT			0xF0
#define CHROMA_DTO2_REG				0x1A
	#define CHROMA_DTO2_DEFAULT			0x7C
#define CHROMA_DTO3_REG				0x1B
	#define CHROMA_DTO3_DEFAULT			0x0F

	#define CHROMA_DTO0					0x21
	#define CHROMA_DTO1					0xF0
	#define CHROMA_DTO2					0x7C
	#define CHROMA_DTO3					0x1F


// Active video horizontal start time, 0x2E
//
// Active video horizontal width, 0x2F
//	Add 640 to this register
#define HACT_START_REG				0x2E
	#define HACT_START_DEFAULT			0x82
#define HACT_WIDTH_REG				0x2F
	#define HACT_WIDTH_DEFAULT			0x50
	
	#define HACT_START					0x82
	#define HACT_WIDTH					0x50
	
//Active video vertical start, 0x30
//
// Active video vertical height, 0x31
//	add 384 to this register, specify the height by the number of half lines
#define VACT_START_REG				0x30
	#define VACT_START_DEFAULT			0x22
#define VACT_HEIGHT_REG				0x31
	#define VACT_HEIGHT_DEFAULT			0x61

	#define VACT_START					0x24
	#define VACT_HEIGHT					0x61

// Vsync time constant, 0x39
//	[7]	set the output field polarity
//		0: field=1 for odd fields, field=0 for even fields (default)
//		1: field=0 for odd fields, field=1 for even fields
//	[6]	flip even/odd fields
//	[5]	delay detection of even fields by 1 vertical line (default=0)
//	[4]	delay detection of odd fields by 1 vertical line (default=0)
//	[3:2] control the field detection logic (default=10)
//	[1:0] set the vertical PLL time constant
//		00: fast. only useful if the vloop_cntl is not 11. Internal values are 2 & 1
//		01: moderate. Internal values are 1 & 1/4
//		10: slow. Internal values are 1/2 & 1/16 (default)
//		11: very slow. Most useful for noisy signals. Internal values are 1/4 & 1/2
#define VSYNC_TIME_REG				0x39
	#define VSYNC_TIME_DEFAULT			0x0A
	#define VSYNC_TIME					0x8A

// Soft reset, 0x3F
//	[7:1] reserved
//	[0]	write 1 to reset initial values for comb filter
#define SOFT_RESET_REG					0x3F
	#define SOFT_RESET					0x01

// Luminance peaking control, 0x80
//	
#define LUMINANCE_PKCTRL_REG		0x80
	#define LUMINANCE_PKCTRL_DEFAULT	0x04
	#define LUMINANCE_PKCTRL			0x05

// Comb filter configuration, 0x82
//	[7]	reserved
//	[6]	used to reduce phase-error artifacts in the comb filter's luma-path. 
//		should be set for VCR signals. Default=1
//	[5]	When set, this will turn on the pal_perr(P2_82[6]) when VCR signal is detected
//		Default=0
//	[4]	used to select the bandpass filter used in the comb-filter.
//		Should be set to 1 for PAL mode. Default=0
//	[3:2] reserved
//	[1:0] used to determine how many incorrect lines are used for the pal switch 
//		circuit before switching. Use a higher level for noisy signals.
//		Default=2
#define COMB_FILTERCFG_REG			0x82
#define COMB_FILTERCFG_DEFAULT		0x42
#define COMB_FILTERCFG				0x42
	



//===========================================================	
//===========================================================	
//===========================================================	
#define ADC_PLLDIV_H  			0x16//0x00
#define ADC_PLLDIV_L  			0x15//0x01
#define ADC_VCOCP     			0x17//0x02
#define ADC_PHASE					0x03
#define ADC_CLPL					0x04
#define ADC_CLDU					0x05
#define ADC_FHSOPW				0x06
#define ADC_RGAIN					0x07
#define ADC_GGAIN					0x08
#define ADC_BGAIN					0x09
#define ADC_ROFF					0x0A
#define ADC_ROFF_DEFAULT			0x0A
#define ADC_GOFF					0x0B
#define ADC_BOFF					0x0C
#define ADC_FBHSYNC    			0x0E
#define ADC_TEST_MODE			0x0F
	#define SLTSSYNC		0x80
	#define CKBYP			0x01
#define ADC_SYNC_ROUT			0x10
	#define HREFSEL 		0x08
	#define CSTSEL       0x04
	#define ADCVSSEL     0x02

/* Sync Detection Regs */
#define CS_CFG	      			0x12
#define CS_RST        			0x13
#define csCSDDONE				0x80 	//Bit of CS_RST
#define csFSTTOOFAST			0x10    //Bit of CS_RST
#define csCSUNSTBL				0x08    //Bit of CS_RST

#define SYNCSTATUS	 			0x1f
	#define SCHKRDY	 	0x80
  	#define VIPALIVE     0x08
  	#define SOGALIVE     0x04
  	#define HSALIVE      0x02
  	#define VSALIVE      0x01

/* Input capture register 0x00 - 0x2f */
#define FRM_STATUS    			0x30
	#define EXVSSH			0x20
	#define ITLCPRO		0x02
#define SRC_SEL       			0x31
	#define IS_SPMD		0x20
	#define IS_SEl			0x10
	#define VIN_EN			0x08
	#define EN_VSOFST		0x04
	#define EN_HSOFST		0x02
	#define INT_EDGE		0x01
#define ORG_FCNT      			0x34
#define TM_1MS_L      			0x35
#define TM_1MS_H      			0x36
#define V_MISS_CNT    			0x37
//#define H_MISS_CNT_L  			0x38
//#define H_MISS_CNT_H  			0x39
//#define VSYNC_DLT     			0x3A
//#define HSYNC_DLT     			0x3B
#define UDHSIZE_L     			0x3C
#define UDHSIZE_H     			0x3D
#define UDVSIZE_L     			0x3E
#define UDVSZIE_H     			0x3F
#define CAP_CTRL      			0x67
#define INT_STATUS    			0x32
	#define ITLCFLG		0x40
#define INT_MASK      			0x33
#define ATKACC        			0x50
#define ATKACC_0      			0x54
#define ATKACC_1      			0x55
#define ATKACC_2      			0x56
#define ATKACC_3      			0x57
#define HS_PERIOD_L   			0x58
#define HS_PERIOD_H   			0x59
#define VS_PERIOD_L   			0x5a
#define VS_PERIOD_H   			0x5b
#define HS_WIDTH_L    			0x5c
#define HS_WIDTH_H    			0x5d
#define VS_WIDTH_L    			0x5e
#define VS_WIDTH_H    			0x5f

/* Auto Position Regs */
#define BOUNDCTR				0x26
#define THRESHOLD				0x27
#define POS_LB_L				0x28
#define POS_LB_H				0x29
#define POS_RB_L				0x2A
#define POS_RB_H				0x2B
#define POS_TB_L				0x2C
#define POS_TB_H				0x2D
#define POS_BB_L				0x2E
#define POS_BB_H				0x2F

#define HSYCOFS_L				0x41
#define HSYCOFS_H				0x42
#define VSYCOFS_L				0x43
#define VSYCOFS_H				0x44			  
#define HATVC_L       			0x48
#define HATVC_H       			0x49
#define VATVR_L       			0x4A
#define VATVR_H       			0x4B
#define HSST_L        			0x4C
#define HSST_H        			0x4D
#define VSST_L        			0x4E
#define VSST_H        			0x4F

/* Scaling Control */
#define DCLKI_IS_FASTER			0x10
#define INV_VIDEOF				0x20
#define SCALING_CTRL  			0x70
#define COEF_DATA_PORT  		0x71
#define SC_HOR_H1     			0x72
#define SC_HOR_H2     			0x73
#define SC_VER_V1     			0x74
#define SC_VER_V2     			0x75

/* Image Control */
#define IMG_FUN_CTRL  			0x90
	#define GAMMA_R		0xc0
	#define GAMMA_G		0x80
	#define GAMMA_B		0x40
	#define GAMMA_RGB	0x00//0x3F
	#define ENCONTRAST	0x10
	#define ENBRIGHT	0x08
	#define ENCSC		0x04
	#define ENGAMMA		0x02
	#define ENDITHER	0x01
    #define PATTERN_CTRL  			0x91
	#define EFMCLR			0x80
#define DIGI_CONTRASTR     			0x92
#define DIGI_CONTRASTG     			0x93
#define DIGI_CONTRASTB     			0x94
#define DIGI_BRIGHTR       			0x96
#define DIGI_BRIGHTG       			0x97
#define DIGI_BRIGHTB       			0x98
#define YCoefCSC					0x97
#define CrCoef_R					0x98
#define CbCoef_G					0x99
#define CrCoef_G					0x9A
#define CbCoef_B					0x9B
#define GAMMA_ADDR     			0x93
#define GAMMA_DATA    			0x94
#define DITHERING     			0x9C

/* OSD1 register definition */
#define OSD1_CFG_INDEX 			0xA0  //OSD1 RAM Address Port of Starting Access (LSB A[7:0] first, then MSB A[12:8]).
#define OSD1_CFG_DATA  			0xA1  //OSD1 RAM Data Port (Low Byte first, then High Byte). After two Writes, the address will be increased by 1.
#define OSD1_RAM_Addr    			0xA2
#define OSD1_RAM_Data    			0xA3

/* OSD2 register definition */
#define OSD2_CFG_INDEX 			0xA8
#define OSD2_CFG_DATA  			0xA9
#define OSD2_RAM_Addr    		0xAA   //OSD2 RAM Address Port of Starting Access (LSB A[7:0] first, then MSB A[12:8]).
#define OSD2_RAM_Data    		0xAB   //OSD2 RAM Data Port (Low Byte first, then High Byte). After two Writes, the address will be increased by 1.
#define OSD_RAM_AL    			0xA2
#define OSD_RAM_AH    			0xA3
#define OSD_RAM_DL    			0xA4
#define OSD_RAM_DH    			0xA5



     //Central Bus Configuration Port Register Set

     #define  CBus_Address_LSB  0xAD
     #define  CBus_Address_MSB  0xAE
     #define  CBus_Data         0xAF

  
/* Output timing Control */


#define POUT_CTL_1    			0xC0
	#ifdef TCON
	#define PSYNC_TCON_SW	0x08
	#else
	#define PSYNC_TCON_SW	0x00
	#endif
#define POUT_CTL_3    			0xC1
#define POUT_VSYNC_CTL 			0xC2
	#define PSYNC_STR			0x10
	#define EN_SAVE_REC		    0x04
	#define IGNORE_VSYNC		0x02
#define PV_DELAY_L    			0xC3
#define PV_DELAY_H              0xC4
#define sPanel_HS_Delay         0xC5
#define Serial_RGB_Sync_Width_REG         0xC6
    #define Serial_RGB_Sync_Width_DEF     0x85
#define Output_RGB_Reordering_REG         0xC7
    #define Output_RGB_Reordering_DEF     0x85
#define PLLDIV_F      			0xC8
#define PLLDIV_I      			0xC9
#define PLLDIV_O      			0xCA
#define PLLCFG_1      			0xCB
#define PLLCFG_2      			0xCC
#define Output_LLCK_Control_2_REG    0xCD
#define Delta_Type_Panel_Control_REG 0xCE

#define KS_Step_LSB_REG      			0xD0        //Key Stone Step LSB Register
#define KS_Step_MSB_REG      			0xD1        //Key Stone Step MSB Register
#define KS_Hmax_REG       			    0xD2        //Key Stone Maximum Black Dot Register
#define KS_REG      			        0xD3        //Key Stone Register
     #define KS_DEF      			    0x58
#define KS_RESET_REG      			    0xD4        //Key Stone Reset Register
#define KS_Coef_Data_Port_REG      		0xD5        //Key Stone Coef Data Port Register

#define HMDISP_STR_REG      			0xD8        //Display Window Horizontal Start Register
#define VMDISP_STR_REG      			0xDA        //Display Window Vertical Start Register
#define HMDISP_SIZE_LSB_REG      		0xDC        //Display Window Horizontal Size LSB Register
#define HMDISP_STR_MSB_REG      		0xDD        //Display Window Horizontal Size MSB Register
#define VMDISP_SIZE_LSB_REG      		0xDE        //Display Window Vertical Size LSB Register
#define VMDISP_SIZE_MSB_REG      		0xDF        //Display Window Vertical Size MSB Register

            // Global Control Register Set

/* Power Management */
#define POWER_REG     			0xE0
 	#define PDADC_B    	0x80
 	#define TPDB	    	0x40
 	#define PDMD       	0x10
 	#define PDPLL_B    	0x08
 	#define PDRX_B     	0x04
 	#define PDC_B      	0x02
 	#define PWDNTC     	0x01
#define LVDS_CFG0     			0xD0

//Output Pin Configuration
#define   Output_Pin_Configuration   0xE1
#define   Output_both_RowSTV_ColSTH  0x00
#define   Output_both_UD_RL          0x0C


#define Shadow_Control_Configuration   0xE2      //Shadow Control Configuration
#define DAC_Power_Management    	   0xE3      //DAC Power Management
#define DAC_Pow_MNG                    0x1F

#define Analog_Output_Current1_REG	   0xE4     //Analog Output Current 1 Register
#define Analog_Output_Current1_DEF	   0xFF
#define Analog_Output_Current2_REG     0xE5     //Analog Output Current 2 Register
#define Analog_Output_Current2_DEF	   0xFF
#define Power_Down_REG                 0xE6     //Power Down Register
#define Power_Down                     0x10      
                                                 
#define CCFL_LED_CON_REG			   0xE7      //CCFL/LED Control Register
#define PWM1_General_CON_REG           0xE8      //PWM_1 General Control Register
#define PWM1_General_CON               0xF7

#define PWM1_Active_High_Time_Counter_REG           0xE9      //PWM_1 Active High Time Counter Register
#define PWM4_General_Control_REG                    0xEA      //PWM_4 General Control Register
#define PWM4_Active_High_Time_Counter_REG           0xEB      //PWM_4 Active High Time Counter Register
#define GPOD_Pin_Control_REG                        0xEE      //GPOD Pin Control Register
#define Shutdown_Control_Reg                        0xEF      //Shutdown Control Register
#define Serial_Bus_Slave_Device_Address_REG         0xF0      //Serial Bus Slave Device Address Register
#define Serial_Bus_Control_REG                      0xF1      //Serial Bus Control Register
#define Foundry_ID_REG                              0xF3      //Foundry ID Register
#define Chip_ID_REG                                 0xF4      //Chip ID Register
#define Revision_ID_Register                        0xF5      //Revision ID Register
#define Date_Code_ID_REG                            0xF6      //Date Code ID Register
#define Wakeup_Control_REG1                         0xFC      //Wakeup Control Register 1
#define Wakeup_Control_REG2                         0xFD      //Wakeup Control Register 2
#define Pin_Function_Select_REG                     0xFE      //Pin Function Select Register
#define Pin_Function_Select                         0x1C
#define Page_Select_REG                             0xFF      //Page Select Register

        //Serial Bus Register Set Page 1
             //TCON Register Set

#define TCON_Control_REG                            0x20       //Timing Controller (TCON) Control Register
#define Timing_Protocol_Polarity_Control_REG      0x21       //Timing Protocol & Polarity Control Register
#define CDLPPLM_LSB_REG                             0x22       //Column Driver Latch Pulse Placement LSB Register
#define CDLPPLM_MSB_REG                             0x23       //Column Driver Latch Pulse Placement MSB Register
#define Column_Driver_Latch_Pulse_Duration_Control_REG 0x24    //Column Driver Latch Pulse Duration Control Register
#define POLPLM_LSB_REG                              0x25       //POL Placement LSB Register
#define POLPLM_MSB_REG                              0x26       //POL Placement MSB Register
#define CLKV_Placement_LSB_REG                      0x27       //CLKV Placement LSB Register
#define CLKV_Placement_MSB_REG                      0x28       //CLKV Placement MSB Register
#define CLKV_Duration_LSB_REG                       0x29       //CLKV Duration LSB Register
#define CLKV_Duration_MSB_REG                       0x2A       //CLKV Duration MSB Register
#define STH_Position_Placement_REG                  0x2B       //STH Position Placement Register
#define Gate_Driver_Pre_Driving_REG                 0x2D       //Gate Driver Pre-Driving Register
#define Double_Scan_CLKV_Placement_LSB_REG          0x2E       //Double Scan CLKV Placement LSB Register
#define Double_Scan_CLKV_Placement_MSB_REG          0x2F       //Double Scan CLKV Placement MSB Register
#define Row_Driver_Configuration_REG                0x30
#define Gate_Driver_OE_Pulse_Position_Placement_LSB_REG 0x31   //Gate Driver OE Pulse Position Placement LSB Register
#define Gate_Driver_OE_Pulse_Position_Placement_MSB_REG 0x32   //Gate Driver OE Pulse Position Placement MSB Register
#define Gate_Driver_OE_Pulse_Duration_LSB_Register  0x33       //Gate Driver OE Pulse Duration LSB Register
#define Gate_Driver_OE_Pulse_Duration_MSB_Register  0x34       //Gate Driver OE Pulse Duration MSB Register
#define STV_Offset_REG                              0x35       //STV Offset Register

           //Infra-Red Register Set

#define   IR_Sampling_Tick_LSB_REG                  0x40    //IR Sampling Tick LSB Register
#define   IR_Sampling_Tick_MSB_REG                  0x41    //IR Sampling Tick MSB Register
#define   IR_Stream1_REG                            0x42    //IR Stream 1~4 Register (when IR_Counter_Mode=0)
#define   IR_Stream2_REG                            0x43    //IR Duration 1~3 Register (when IR_Counter_Mode=1)
#define   IR_Stream3_REG                            0x44
#define   IR_Stream4_REG                            0x45           
#define   IR_Duration1_REG                          0x42
#define   IR_Duration2_REG                          0x43
#define   IR_Duration3_REG                          0x44
#define   IR_Stream_1_REG                           0x47

              //GPIO Register Set


#define   oe_GPOA_REG                                   0x50
#define   o_GPOA_REG                                    0x51
#define   i_GPOA_REG                                    0x52
#define   oe_GPOB_REG                                   0x54
#define   o_GPOB_REG                                    0x55
#define   i_GPOB_REG                                    0x56
#define   En_Rise_GPIC_REG                              0x57
#define   En_Fall_REG                                   0x58
#define   Int_GPIC_REG                                  0x59
#define   i_GPIC_REG                                    0x5A
#define   En_DeBnc_GPIC                                 0x5B
#define   GPIO_Output_REG                               0x5C
#define   GPIO_Status_and_Interrupt_REG                 0x5D
#define   GPIO_Interrupt_Trigger_REG                    0x5E
#define   GPIO_Control_REG                              0x5F
#define   GPOD_REG                                      0x8C

       // Digital PWM Register Set

#define   PWM23_Limit_Register1                         0x60
#define   PWM23_Limit_Register2                         0x61
#define   PWM2_Control_REG                              0x62
#define   PWM2_DUTY_REG                                 0x63
#define   PWM2_Period_REG                               0x64
#define   PWM3_Control_REG                              0x65
#define   PWM3_Duty_REG                                 0x66
#define   PWM3_Period_REG                               0x67
#define   CCFL_Control_REG                              0x68
#define   PWM2_Range_REG_1                              0x69
#define   PWM2_Range_REG_2                              0x6A
#define   PWM3_Range_REG_1                              0x6B
#define   PWM3_Range_REG_2                              0x6C
#define   PWM2_Trace_REG                                0x6D
#define   PWM3_Trace_REG                                0x6E
#define   PWM23_Read_Value_REG                          0x6F
#define   PWM_Tip_Selection                             0x7F


                 //SAR Register Set

#define   SAR1_Control_REG                              0x73
#define   SAR1_Real_Time_Value_REG                      0x74
#define   SAR1_Threshold_REG                            0x75
#define   SAR1_Stable_Value_REG                         0x77
#define   SAR1_Source_Selection_REG                     0x78

                  //TOUCH PANEL REGISTER SET

#define   TP_CONTROL_REG1                               0x7C
#define   TP_CONTROL_REG2                               0x7D
#define   PWM_TIP_SELECTION                             0x7F

                  //GPO REGISTER SET
                  //GPOD REGISTER


                 //SPI AND MCU BIU REGISTER SET
#define  MCU_COMMU_BUFFER_REG0              0xE0
#define  MCU_COMMU_BUFFER_REG1              0xE1
#define  MCU_COMMU_BUFFER_REG2              0xE2
#define  MCU_COMMU_BUFFER_REG3              0xE3
#define  MCU_COMMU_BUFFER_REG4              0xE4
#define  MCU_COMMU_BUFFER_REG5              0xE5
#define  MCU_COMMU_BUFFER_REG6              0xE6
#define  MCU_COMMU_BUFFER_REG7              0xE7
#define  MCU_COMMU_BUFFER_REG8              0xE8
#define  MCU_COMMU_BUFFER_REG9              0xE9
#define  MCU_COMMU_BUFFER_REG10             0xEA
#define  MCU_COMMU_BUFFER_REG11             0xEB
#define  MCU_COMMU_BUFFER_REG12             0xEC
#define  MCU_COMMU_BUFFER_REG13             0xED
#define  MCU_COMMU_BUFFER_REG14             0xEE
#define  MCU_COMMU_BUFFER_REG15             0xEF

#define  SPI_INSTRUCTION_REG                0xF0
#define SPI_ADDR_REG1                       0xF1
#define SPI_ADDR_REG2                       0xF2
#define SPI_ADDR_REG3                       0xF3  
#define SPI_SINGLE_WR_DATA_REG              0xF4
#define SPI_CONTROL_REG                     0xF5
#define SPI_READBACK_DATA_REG               0xF6
#define SPI_DEVICE_ID_REG                   0xF7
#define SPI_MANUFACTURE_ID_REG              0xF8
#define SPI_DMA_LOWER_ADDRESS_REG           0xF9
#define SPI_DMA_HIGH_ADDRESS_REG            0xFA
#define SPI_DMA_COUNT_LSB_REG               0xFB
#define SPI_DMA_TRANSFER_MSB_REG            0xFC
#define BIO_CACHE_CONTROL_REG               0xFD
#define BIO_CONTROL_REG                     0xFE
#define PAGE_SELECT_REG                     0xFF

                // Color Space Convert Register Set

#define  YUV_To_RGB_Convert_REG1                        0xB0
#define  YUV_To_RGB_Convert_REG2                        0xB1
#define  YUV_To_RGB_Convert_REG3                        0xB2
#define  YUV_To_RGB_Convert_REG4                        0xB3
#define  YUV_To_RGB_Convert_REG5                        0xB4
#define  YUV_To_RGB_Convert_REG6                        0xB5
#define  YUV_To_RGB_Convert_REG7                        0xB6
#define  YUV_To_RGB_Convert_REG8                        0xB7
#define  YUV_To_RGB_Convert_REG9                        0xB8

                //Color Probing Register Set

#define Color_Range_and_Probing_Control_REG             0xC0
#define Probed_R_Channel_Color_Value_REG                0xC1
#define Probed_G_Channel_Color_Value_REG                0xC2
#define Probed_B_Channel_Color_Value_REG                0xC3
#define Probed_R_Channel_Color_Range_LSB_REG            0xC4
#define Probed_R_Channel_Color_Range_MSB_REG            0xC5
#define Probed_G_Channel_Color_Range_LSB_REG            0xC6
#define Probed_G_Channel_Color_Range_MSB_REG            0xC7
#define Probed_B_Channel_Color_Range_LSB_REG            0xC8
#define Probed_B_Channel_Color_Range_MSB_REG            0xC9
#define Probed_Dot_Coordinate_X_LSB_REG                 0xCA
#define Probed_Dot_Coordinate_X_MSB_REG                 0xCB
#define Probed_Dot_Coordinate_Y_LSB_REG                 0xCC
#define Probed_Dot_Coordinate_Y_MSB_REG                 0xCD
#define Probed_Dot_Size_REG                             0xCE

           // ITU - 656 Decoder Register Set



#define HS_DELAY656                                     0xD0      //ITU-656 Decoder HS Delay Register
#define ITU_656_Decoder_HS_Pulse_Width_REG              0xD2
#define ITU_656_Decoder_VS_Delay_REG                    0xD3
#define ITU_656_Decoder_VS_Pulse_Width_REG              0xD4
#define ITU_656_Decoder_HDE_Start_REG                   0xD5
#define ITU_656_Decoder_HDE_Size_LSB_REG                0xD7
#define ITU_656_Decoder_HDE_Size_MSB_REG                0xD8
#define ITU_656_Decoder_Odd_Field_VDE_Start_REG         0xD9
#define ITU_656_Decoder_Odd_Even_Field_VDE_Start_REG    0xDA
#define ITU_656_Decoder_VDE_Size_LSB_REG                0xDB
#define ITU_656_Decoder_VDE_Size_MSB_REG                0xDC
#define ITU_656_Decoder_VCLK_Tuning_REG                 0xDE
#define ITU_656_Decoder_Format_Control_REG              0xDF



          // Serial Bus Register Set Page 2
         // Y/C Separation and Chroma Decoder Register Set

#define Video_Source_Selection_of_Comb_Filter_REG       0x00
#define Bandwidth_Control_REG                           0xO1
#define Y_C_AGC_Enable_REG                              0x02
#define Comb_Filtering_Mode_REG                         0x03
#define Luma_AGC_Target_Value_REG                       0x04
#define Y_C_Output_Control_REG                          0x07
#define Luma_Contrast_REG                               0x08
#define Luma_Brightness_REG                             0x09
#define Chroma_Saturation_REG                           0x0A
#define Chroma_Hue_Phase_REG                            0x0B 
#define Chroma_AGC_REG                                  0x0C
#define AGC_Peak_Nominal_REG                            0x10
#define Chroma_DTO_Incremental_0_REG                    0x18
#define Chroma_DTO_Incremental_1_REG                    0x19
#define Chroma_DTO_Incremental_2_REG                    0x1A
#define Chroma_DTO_Incremental_3_REG                    0x1B
#define Active_Video_Horizontal_Start_Time_REG          0x2E
#define Active_Video_Horizontal_Width_REG               0x2F
#define V_START_REG                                     0x30
#define V_WIDTH_REG                                     0x31
#define Comb_Video_Status_Register1                     0x3A
#define Comb_Video_Status_Register2                     0x3B
#define Comb_Video_Status_Register3                     0x3C
#define Soft_Reset_REG                                  0x3F
#define Luminance_Peaking_Control_REG                   0x80
#define Comb_Filter_Configuration_REG                   0x82
#define Comb_Lock_Configuration_REG                     0x83
#define DDS_Fsc1_Frequency1                             0xA0
#define DDS_Fsc1_Frequency2                             0xA1
#define DDS_Fsc1_Frequency3                             0xA2
#define DDS_Fsc1_Frequency4                             0xA3
#define DDS_Fsc2_Frequency1                             0xA4
#define DDS_Fsc2_Frequency2                             0xA5
#define DDS_Fsc2_Frequency3                             0xA6
#define DDS_Fsc2_Frequency4                             0xA7
#define DDS_Fsc3_Frequency1                             0xA8
#define DDS_Fsc3_Frequency2                             0xA9
#define DDS_Fsc3_Frequency3                             0xAA
#define DDS_Fsc3_Frequency4                             0xAB
#define Line_Fsc_Start                                  0xAC
#define Line_Fsc_End                                    0xAD
#define Window_Fsc_Start                                0xAE
#define Window_Fsc_End                                  0xAF
#define Window_Fsc3_Start                               0xB0
#define Window_Fsce_End                                 0xB1
#define Spectrum_Analysis                               0xB2
#define Component_Chroma_LPF                            0xC1


#define LINE_WORD        	0x20
#define X_SIZE           	31
#define Y_SIZE           	13
#define SUB_X_SIZE		 	31
#define MAIN_Y_SIZE		 	20
#define POS_Y_SIZE		 	9
#define IMAGE_Y_SIZE		 	14

#define X_OFFSET         	0
#define Y_OFFSET         	1


//#define BLACK_WHITE		0x2f
#define BLACK_BLUE			0x21
#define BLACK_PW_BLUE		0x23
#define BLACK_ORANGE		0x24
#define BLACK_GREEN    		0x25
#define BLACK_L_GRAY		0x26
#define BLACK_OLIVE			0x27
#define BLACK_D_GRAY		0x28
#define BLACK_RED  			0x29
#define BLACK_PURPLE		0x2A
#define TITLE_ATTR			0x62
#define GRAY_ORANGE			0x64
#define GRAY_PW_BLUE		0x63
#define HEADER_ATTR         0x2e
#define GRAY_D_GRAY			0x68
#define TRANSPARENT			0x00
#define ROW_ATTR            0x00   //80
#define HIGHLIGHT_ATTR      0xA0   //c0

/* PanelLink Reciever */
#define RXCFG0     			0x20
#define RXCFG1     			0x21
#define RXCFG2     			0x22
#define RXCFG3     			0x23
#define RXCFG4     			0x24
#define RXCFG5     			0x25
#define RXCFG6     			0x26
#define RXCFG7     			0x27
#define RXCFG8     			0x28
#define RXCFG9     			0x29
#define RXCFGA     			0x2A
#define RXCFGB     			0x2B


/* Two Wire Bus  Slave Interface */
#define TW_INTERFACE			0xF1
	#define AUTO_INC	  	0x04
	#define TWO_BUS		0x00
	#define TWO_FOUR_BUS	0x01
	#define TWO_DDC_BUS	0x02
	#define TWO_BVSI_BUS	0x03
#define DID_L					0xf6

/* bit definition */

//#define I2C_FORCE_SEL  0x40
#define TW_FORCE_SEL   0x40
#define IS_SEL         0x10

#define HSYNC_POLARITY 0x02
#define VSYNC_POLARITY 0x01

#define LE_VSYNC       0x20
#define TIME_OUT       0x10
#define HSYNC_CHANGE   0x08
#define VSYNC_CHANGE   0x04
#define HSYNC_MISS     0x02
#define VSYNC_MISS     0x01

/*	not used
#define ATKR           0x02
#define ATKE           0x01
*/

#define SHARPNESS_ON   0x20
#define SHARPNESS_OFF  0xdf
#define CONTRA_ON      0x10
#define CONTRA_OFF     0xef
#define BRIGHT_ON      0x08
#define BRIGHT_OFF     0xf7
#define GAMMAIOTAB_ON  0x04
#define GAMMAIOTAB_OFF 0xfb
#define GAMMA_OFF      0xfd
#define DITHERING_ON   0x01
#define DITHERING_OFF  0xfe



#define OSD2FONTWIDTH12				12
#define OSD2FONTWIDTH16				16

#define OSD2FONTHEIGHT8				 8
#define OSD2FONTHEIGHT10			10
#define OSD2FONTHEIGHT12			12
#define OSD2FONTHEIGHT14			14
#define OSD2FONTHEIGHT16			16
#define OSD2FONTHEIGHT18			18
#define OSD2FONTHEIGHT20			20
#define OSD2FONTHEIGHT24			24
//-----------------------------------------------------------------------//

//-------------------------- OSD2 Fonts Attribute -----------------------//
#define FontWidth				OSD2FONTWIDTH12
#define FontHeight			   	OSD2FONTHEIGHT12
#define Font1BPNum			   	0
#define Font2BPNum				0//FONT2BPNUM
#define Font4BPNum				FONT4BPNUM
#define Font2BPIndexStr			Font1BPNum
#define Font4BPIndexStr			Font2BPIndexStr+Font2BPNum
//-----------------------------------------------------------------------//

//------------------------------ Menu Attribute -------------------------//
#define MENU1					1
#define MENU2					2
#define Menu1StartX				1
#define Menu1StartY				1
#define Menu1Width				32
#define Menu1Height				20	 

#define Menu2StartX				400
#define Menu2StartY				200
#define Menu2Width				32
#define Menu2Height				20	

//-----------------------------------------------------------------------//

//-------------------------- OSD2 Memory Address ------------------------//
#if (FontWidth==OSD2FONTWIDTH12)
#define Font1BPDataStrAdr		0x0000
#define Font2BPDataStrAdr		Font1BPDataStrAdr+Font1BPNum*((FontHeight*3+2)>>2)
#define Font4BPDataStrAdr		Font2BPDataStrAdr+Font2BPNum*((FontHeight*3)>>1)
#define Menu1StrAdr				Font4BPDataStrAdr+Font4BPNum*(FontHeight*3)
#define Menu1EndAdr				Menu1StrAdr+(Menu1Width+4)*Menu1Height				
#define Menu2StrAdr			   	Menu1EndAdr+0x0004
#define Menu2EndAdr  			Menu2StrAdr+(Menu2Width+4)*Menu2Height
#elif (FontWidth==OSD2FONTWIDTH16)
#define Font1BPDataStrAdr		0x0000
#define Font2BPDataStrAdr		Font1BPDataStrAdr+Font1BPNum*FontHeight
#define Font4BPDataStrAdr		Font2BPDataStrAdr+Font2BPNum*FontHeight*2
#define Menu1StrAdr				Font4BPDataStrAdr+Font4BPNum*FontHeight*4
#define Menu1EndAdr				Menu1StrAdr+(Menu1Width+5)*Menu1Height				
#define Menu2StrAdr			   	Menu1EndAdr+0x0004
#define Menu2EndAdr  			Menu2StrAdr+(Menu2Width+5)*Menu2Height
#endif
//------------------------------------------------------------------------//
extern void OSD2Init(void);
//extern void OSD2LoadColor(void);
//extern void OSD2Load4BPFont(void);
//extern void OSD2Load2BPFont(void);
//extern void OSD2Load1BPFont(void);
//extern void OSD2ShowLine(uCHAR *string,uCHAR x,uCHAR y,uCHAR cColor,uCHAR cLength,uCHAR cBlink);
//extern void OSD2Show2BPLine(uCHAR *string,uCHAR x,uCHAR y,uCHAR cLength,uCHAR cBlink,uCHAR MenuIndex);
//extern void OSD2Show4BPLine(uCHAR *string,uCHAR x,uCHAR y,uCHAR cLength,uCHAR cBlink,uCHAR MenuIndex);
#define OSD_CTRL         	0x00
#define CHAR_DLY_0       	0x01
#define CHAR_DLY_1       	0x02
#define CHAR_DLY_2       	0x03
#define CHAR_FONT_SIZE   	0x04
#define CHAR_RAM_BASE_A  	0x05
#define CHAR_BS_CTRL     	0x06
#define CHAR_BS_COLOR    	0x07
#define CHAR_HEIGHT_CTRL 	0x08
#define BLINK_CTRL       	0x09
#define BW_WH_UPPER      	0x0a
#define BW_W             	0x0b
#define BW_H             	0x0c
#define BD_ENLARGE       	0x0d
#define OSD_LUT_RAM_DATA 	0x0e
#define WIN1_Y_START     	0x10
#define WIN1_Y_END       	0x11
#define WIN1_X_START     	0x12
#define WIN1_X_END       	0x13
#define WIN1_SHADOW_SIZE 	0x14
#define ALPHA_BLD_CTRL   	0x1c
#define CHAR_RAM_END_A   	0x1e


//#ifdef T138AF 

#define OSD1_Enable_Blinking_Register         	0x00
#define Font_Size       	                    0x01
#define Char2BP_Font_Index_Base      	        0x02
#define Char4BP_Font_Index_Base       	        0x03
#define Char2BP_Font_Memory_Base_Address_LSB   	0x04
#define Char2BP_Font_Memory_Base_Address_MSB  	0x05
#define Char4BP_Font_Memory_Base_Address_LSB    0x06
#define Char4BP_Font_Memory_Base_Address_MSB    0x07
#define OSD1_Color_LUT_Address_port 	        0x08
#define OSD1_Color_LUT_Data_Port       	        0x09
#define OSD1_Window_Shadow      	            0x0a
#define Global_Alpha_Blending_Control           0x0b
#define Char1BP_color_high_bits_offset          0x0c
#define ROM_Font_Index_Base       	            0x0d
#define Revision_ID 						 	0x0f
#define Menu_1_Enable   						0x10
#define Menu_1_Start_Address_LSB       	        0x11
#define Menu_1_Start_Address_MSB     	        0x12
#define Menu_1_End_Address_LSB       	        0x13
#define Menu_1_End_Address_MSB 	                0x14
#define ROM_Font_Memory_Base_Address_LSB   	    0x16
#define ROM_Font_Memory_Base_Address_MSB   	    0x17
#define	Menu_2_Enable                           0x18
#define	Menu_2_Start_Address_LSB                0x19
#define	Menu_2_Start_Address_MSB                0x1a	   
#define	Menu_2_End_Address_LSB                  0x1b
#define	Menu_2 End_Address_MSB                  0x1c
#define	BMP_Control_Register                    0x20
#define	BMP_Start_Address_LSB                   0x21
#define	BMP_Start_Address_MSB                   0x22
#define	BMP_Alpha_Blending_Control              0x23
#define	BMP_Horizontal_Size_LSB                 0x24
#define	BMP_Horizontal_Size_MSB                 0x25
#define	BMP_Vertical_Size_LSB                   0x26
#define	BMP_Vertical_Size_MSB                   0x27
#define	BMP_Position_Horizontal_Start_LSB       0x28
#define	BMP_Position_Horizontal_Start_MSB       0x29
#define	BMP_Position_Vertical_Start_LSB         0x2a
#define	BMP_Position_Vertical_Start_MSB         0x2b
#define	BMP_LUT_Base_Address                    0x2c
#define	BMP_Background_Color                    0x2d
#define	Block_Write_Data_LSB                    0x40
#define	Block_Write_Data_MSB                    0x41
#define	Block_Write_Starting_Address_LSB        0x42
#define	Block_Write_Starting_Address_MSB        0x43
#define	Block_Write_Count                       0x44
#define	Block_Write_Control                     0x45

 //#endif

#define IndexNumOffset				0
#define IndexCharacterOffset		0


//Background foreground
//Background only in even  ,bit 4 set 1 --> blink
#define PWBLUE_GREY        	0xc3 //0xef
#define BLUE_GREY       	0xce //0xef
#define BLUE_WHITE        	0x4F
#define DBLUE_WHITE        	0x4F
#define YELLOW_RED        	0xC6
#define YELLOW_DBLUE    	0xC4
#define GREEN_WHITE     	0x8F
#define DBLUE_RED        	0x46
#define RED_YELLOW        	0x6C
#define LBLUE_WHITE        	0xeF
#define LBLUE_GREEN        	0xA5
#define LBLUE_RED        	0xc7//0xd7
#define BLACK_WHITE        	0x2F
#define BLUE_PURPLE        	0x4b

#define BLACK_GREY      	0xc2 //0xe2
#define WHITE_PURPLE    	0x4f
#define WHITE_GREY        	0x8f
#define GUAGE_GAP 			0x02
#define COL_TITLE        	BLUE_WHITE//YELLOW_RED
#define COL_NORMAL       	BLUE_WHITE//BLACK_WHITE
#define COL_FOCUS        	DBLUE_WHITE
#define COL_GAUGE          	BLUE_WHITE//GREEN_WHITE
#define COL_SELECT			BLACK_GREY
#define COL_ICON			PWBLUE_GREY
#define COL_RED				DBLUE_RED
#define COL_GREEN			DBLUE_RED
#define COL_BLUE 			DBLUE_RED
#define COL_CLEAR			0x00
#define COL_NOSUPPORT		RED_YELLOW
#define COL_NOSIGNAL		YELLOW_DBLUE
#define COL_FRTYMENU		LBLUE_WHITE
#define COL_FRAME			LBLUE_GREEN
#define COL_PROCESS			LBLUE_RED

#define LINE_LENGTH			27
#define GAUGE_LENGTH   		20

/*#if (defined T102)|(defined T112)|(defined T116)|(defined T118)
	#define	FONT_SIZE6W16H		0x83
	#define	FONT_SIZE8W16H		0x84
	#define	FONT_SIZE12W18H		0x96
    #define	FONT_SIZE12W16H		0x86
#elif (defined T106)
	#define	FONT_SIZE12W16H		0x00
	#define	FONT_SIZE16W16H		0x10
	#define	FONT_SIZE12W18H		0x20
	#define	FONT_SIZE16W18H		0x30
// kenny 20070130
#elif ((defined T108) || (defined T128)) 
	#define	FONT_SIZE12W18H		0x49
// kenny 20070130
#else  // T100A,T101A,T101
*/
	#define	FONT_SIZE10W16H		0x00
	#define	FONT_SIZE12W16H		0x01
	#define	FONT_SIZE14W16H		0x02
	#define	FONT_SIZE16W16H		0x03
	#define	FONT_SIZE10W18H		0x08
	#define	FONT_SIZE12W18H		0x09
	#define	FONT_SIZE14W18H		0x0a
	#define	FONT_SIZE16W18H		0x0b
//#endif

#define WIDTH6					6   // add by Sherman 05'11'04
#define WIDTH8					8   // add by Sherman 05'11'04
#define WIDTH10				    10
#define WIDTH12					12
#define WIDTH14					14
#define WIDTH16					16

#define HEIGHT16				16
#define HEIGHT18				18
#define HEIGHT20				20
#define HEIGHT24				24

#define COL_9300				0
#define COL_6500				1
#define COL_USER				2
#define COL_BRIGHT				3

#define CENTER					1
#define LEFT_BOTTOM				2
#define TOP						3
#define RIGHT_TOP				4

#define	FONT_SIZE				FONT_SIZE12W18H
#define FONT_WIDTH				WIDTH12
#define FONT_HEIGHT				HEIGHT18
enum{BAR_S_MIN =36,BAR_S_1, BAR_S_2, BAR_S_MAX}; //36, 37, 38, 39
enum{BAR_MIN   =40,BAR_1  , BAR_2  , BAR_MAX  }; //40, 41, 42, 43
enum{BAR_E_MIN =44,BAR_E_1, BAR_E_2, BAR_E_MAX}; //44, 45, 46, 47


#define MAIN_MENU_TOTAL_LINES		10
#define SUB_MENU_TOTAL_LINES		7  	//DigiMax OSD Language sub-menu
//#define TOTAL_FONT_NUM	 			sizeof(AllFonts)/sizeof(unsigned char*)
#if (defined T102)|(defined T106)|(defined T112)
#define TOTAL_FONT_NUM					38
#elif (defined T116)
#define TOTAL_FONT_NUM					48
#else
#define TOTAL_FONT_NUM					128
#endif
#define FONT_DATA_START_ADDRESS			0x0000
#define MENU_RAM_START_ADDRESS			((TOTAL_FONT_NUM*FONT_HEIGHT)/32+1)*32
#if (defined T102)|(defined T106)|(defined T112)|(defined T118)|(defined T116)
#define CHAR_MAIN_MENU_START			((MENU_RAM_START_ADDRESS>>4)&0xFF)
#else
#define CHAR_MAIN_MENU_START			((MENU_RAM_START_ADDRESS>>5)&0x7F)
#endif


#if (defined T102)|(defined T106)|(defined T112)
	#define CHAR_RAM_END          		0x40 // 1024/16=0x40
	#define Clean_RAM_END				0x400
#elif (defined T118)
	#define CHAR_RAM_END               	0xc0 // 1024*3/16=0xc0
	#define Clean_RAM_END				0xc00
#elif (defined T116)
	#define CHAR_RAM_END               	0x60 // 1024*1.5/16=0x60
	#define Clean_RAM_END				0x600
#elif ((defined T108) || (defined T128))
	#define CHAR_RAM_END               	0xc0 // 1024*6/32=0xc0
	#define Clean_RAM_END				0x1800
#else
	#define CHAR_RAM_END               	0x60 // 1024*3/32=0x60
	#define Clean_RAM_END				0xc00
#endif



#if (defined T102)|(defined T106)|(defined T112)|(defined T118)
	#ifdef _160_234
	#define OSD_LENGTH			20
	#else
	#define OSD_LENGTH			28
	#endif
#else
	#define OSD_LENGTH			28//24
#endif

#define OSD_LINE_NUM			14//11//kenny 20060403 10
#define NOSIGNAL_LENGTH			13
#define NOSUPPORT_LENGTH 		14
#define COLORCAL_LENGTH	 		23
#define CALDOING_LENGTH	 		18
#define ICON_STAT				0
#define TXT_STAT				3
#define NUM_STAT				25
#define ITEM_STAT				18
#define FCTRY_OSD_LENGTH		25
#define FCTRY_NUM_STAT			20
#define GAUGE_Y  7
//OSD number draw attabite
#define DRAW_BLANK				0x10
#define DRAW_ZERO				0x20

//#if (defined T103)|(defined T100A)|(defined T108)|(defined T128) // kenny 20070130
#define Gauge_Full				0x0b
#define Gauge_Empty 			0x08
/*#else
#define Gauge_Full				0x87
#define Gauge_Empty 			0x83
#endif */














//extern OSDPARAMS code sOSDParamsDef, sOSDParamsMin, sOSDParamsMax;
//void OSDInit(void);
void OSDLoadColor(void);
void OSDSetRamAddr(unsigned int address);

void OSDEventMgr(void);
void OSDOpenMenu(void);
void OSDFuncSelect(void);
void OSDFuncEnter(void);
void OSDFuncEnterVideo(void);
void OSDFuncExit(void);
void OSDFuncExitVideo(void);

void OSDDisable(void);
void OSDEnable(void);
void OSDExit(void);

void OSDShowPage(void);
void OSDShowFactryPage(void);
//void OSDShowLine(uCHAR*,uCHAR,uCHAR,uCHAR,uCHAR);

void OSDMoveCursor(void);
void OSDShowData(void);
void OSDShowVideoData(void);
void OSDDrawGauge(unsigned char cVal, unsigned char cMax, unsigned char x, unsigned char y, unsigned char cColor);
void OSDDrawNum(unsigned char wVal, unsigned char cMax, unsigned char x, unsigned char y, unsigned char cColor, unsigned char cAttr);
void OSDDrawTVFreq(unsigned char wFreq);
void OSDShowTV_Num(unsigned char cTemp);
void OSDDrawBand(unsigned char wFreq);
void OSDNumConvert(unsigned char cNum);
void OSDShowInfo(unsigned char x,unsigned char y,unsigned char z);
void OSDDrawSkip(void);
void OSDShowRESET(int bTemp);

void OSDClearCursor(void);
void OSDCleanLine(unsigned char x,unsigned char y,unsigned char cColor,unsigned char cLength);
void OSDClearPage(void);
void OSDSetLineAttribute(unsigned char cLine,unsigned char cAttribute);
//void OSDShiftSrc(uCHAR cSrc1, uCHAR cSrc2);
void OSDShowSubpage(void);
void OSDDspMessages(unsigned char);
void OSDPosition(unsigned char);
//void OSDTVShowChannel(uCHAR x, uCHAR y, uCHAR cColor, uCHAR cChannel);

void OSDShowSource(void);
void OSDShowNTSC_PAL(void);
void OSDDrawSoundSystem(void);
void OSDShowRatio(void);
//#ifdef TV
void OSDShowTVData(void);
void OSDTVShowChannel(unsigned char cChannel);
void OSDShowTVSource(unsigned char);
//#endif
void OSDShowCCData(unsigned char wVal, unsigned char x, unsigned char y, unsigned char tAttr); // kenny 20050403
void OSDShowItem(unsigned char *str, unsigned char x,unsigned char y);

//#if ((defined T108) || (defined T128))
void Show_Demo_Page(void);
void init_T138AF(void);

//#endif
#endif // __OSDDRAW_H__





